from a10sdk.common.A10BaseClass import A10BaseClass


class Slb(A10BaseClass):
    
    """Class Description::
    SLB related commands.

    Class slb supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param virtual_server_list: {"minItems": 1, "items": {"type": "virtual-server"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"port-list": {"minItems": 1, "items": {"type": "port"}, "uniqueItems": true, "array": [{"required": ["port-number", "protocol"], "properties": {"reset-on-server-selection-fail": {"default": 0, "optional": true, "type": "number", "description": "Send client reset when server selection fails", "format": "flag"}, "ha-conn-mirror": {"default": 0, "optional": true, "type": "number", "description": "Enable for HA Conn sync", "format": "flag"}, "template-ftp": {"description": "FTP port template (Ftp template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "type": "string", "$ref": "/axapi/v3/slb/template/ftp"}, "protocol": {"optional": false, "enum": ["tcp", "udp", "others", "diameter", "dns-tcp", "dns-udp", "fast-http", "fix", "ftp", "ftp-proxy", "http", "https", "mlb", "mms", "mysql", "mssql", "radius", "rtsp", "sip", "sip-tcp", "sips", "smpp-tcp", "spdy", "spdys", "smtp", "ssl-proxy", "tcp-proxy", "tftp"], "type": "string", "description": "'tcp': TCP LB service; 'udp': UDP Port; 'others': for no tcp/udp protocol, do IP load balancing; 'diameter': diameter port; 'dns-tcp': DNS service over TCP; 'dns-udp': DNS service over UDP; 'fast-http': Fast HTTP Port; 'fix': FIX Port; 'ftp': File Transfer Protocol Port; 'ftp-proxy': ftp proxy port; 'http': HTTP Port; 'https': HTTPS port; 'mlb': Message based load balancing; 'mms': Microsoft Multimedia Service Port; 'mysql': mssql port; 'mssql': mssql; 'radius': Radius Port; 'rtsp': Real Time Streaming Protocol Port; 'sip': Session initiation protocol over UDP; 'sip-tcp': Session initiation protocol over TCP; 'sips': Session initiation protocol over TLS; 'smpp-tcp': SMPP service over TCP; 'spdy': spdy port; 'spdys': spdys port; 'smtp': SMTP Port; 'ssl-proxy': Generic SSL proxy; 'tcp-proxy': Generic TCP proxy; 'tftp': TFTP Port; ", "format": "enum"}, "force-routing-mode": {"default": 0, "optional": true, "type": "number", "description": "Force routing mode", "format": "flag"}, "waf-template": {"description": "WAF template (WAF Template Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/waf/template"}, "l7-hardware-assist": {"description": "FPGA assist L7 packet parsing", "format": "flag", "default": 0, "type": "number", "optional": true, "plat-neg-list": ["non-fpga", "soft-ax"]}, "template-persist-ssl-sid": {"description": "SSL session ID persistence (Source IP Persistence Config name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string", "$ref": "/axapi/v3/slb/template/persist/ssl-sid"}, "no-auto-up-on-aflex": {"default": 0, "optional": true, "type": "number", "description": "Don't automatically mark vport up when aFleX is bound", "format": "flag"}, "template-dns": {"description": "DNS template (DNS template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/dns"}, "template-http-policy": {"description": "http-policy template (http-policy template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/http-policy"}, "gslb-enable": {"default": 0, "optional": true, "type": "number", "description": "Enable Global Server Load Balancing", "format": "flag"}, "template-policy": {"description": "Policy Template (Policy template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/policy"}, "use-alternate-port": {"default": 0, "optional": true, "type": "number", "description": "Use alternate virtual port", "format": "flag"}, "ipinip": {"default": 0, "optional": true, "type": "number", "description": "Enable IP in IP", "format": "flag"}, "acl-name-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"acl-name": {"description": "Apply an access list name (Named Access List)", "format": "string", "minLength": 1, "$ref-list": ["/axapi/v3/ip/access-list", "/axapi/v3/ipv6/access-list"], "maxLength": 16, "type": "string"}, "acl-name-src-nat-pool": {"description": "Policy based Source NAT (NAT Pool or Pool Group)", "format": "string", "minLength": 1, "$ref-list": ["/axapi/v3/ip/nat/pool", "/axapi/v3/ipv6/nat/pool", "/axapi/v3/ip/nat/pool-group", "/axapi/v3/ipv6/nat/pool-group"], "maxLength": 128, "type": "string"}, "optional": true, "acl-name-seq-num": {"description": "Specify ACL precedence (sequence-number)", "minimum": 1, "type": "number", "maximum": 32, "format": "number"}}}]}, "stats-data-action": {"description": "'stats-data-enable': Enable statistical data collection for virtual port; 'stats-data-disable': Disable statistical data collection for virtual port; ", "format": "enum", "default": "stats-data-enable", "type": "string", "enum": ["stats-data-enable", "stats-data-disable"], "optional": true}, "template-persist-destination-ip": {"description": "Destination IP persistence (Destination IP persistence template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string", "$ref": "/axapi/v3/slb/template/persist/destination-ip"}, "template-tcp-proxy-server": {"description": "TCP Proxy Config Server (TCP Proxy Config name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/tcp-proxy"}, "template-sip": {"description": "SIP template", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/sip"}, "template-virtual-port": {"description": "Virtual port template (Virtual port template name)", "format": "string", "default": "default", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/virtual-port"}, "conn-limit": {"description": "Connection Limit", "format": "number", "default": 8000000, "optional": true, "maximum": 8000000, "minimum": 1, "type": "number"}, "precedence": {"default": 0, "optional": true, "type": "number", "description": "Set auto NAT pool as higher precedence for source NAT", "format": "flag"}, "template-client-ssl": {"description": "Client SSL Template (Client SSL Config Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/client-ssl"}, "template-persist-cookie": {"description": "Cookie persistence (Cookie persistence template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string", "$ref": "/axapi/v3/slb/template/persist/cookie"}, "template-tcp": {"description": "L4 TCP Template (TCP Config Name)", "format": "string", "default": "default", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/tcp"}, "template-tcp-proxy-client": {"description": "TCP Proxy Config Client (TCP Proxy Config name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/tcp-proxy"}, "template-connection-reuse": {"description": "Connection Reuse Template (Connection Reuse Template Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string", "$ref": "/axapi/v3/slb/template/connection-reuse"}, "service-group": {"description": "Bind a Service Group to this Virtual Server (Service Group Name)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 128, "type": "string", "$ref": "/axapi/v3/slb/service-group"}, "pool": {"description": "Specify NAT pool or pool group", "format": "string", "minLength": 1, "$ref-list": ["/axapi/v3/ip/nat/pool", "/axapi/v3/ipv6/nat/pool", "/axapi/v3/ip/nat/pool-group", "/axapi/v3/ipv6/nat/pool-group"], "optional": true, "maxLength": 128, "type": "string"}, "persist-type": {"optional": true, "enum": ["src-dst-ip-swap-persist", "use-src-ip-for-dst-persist", "use-dst-ip-for-src-persist"], "type": "string", "description": "'src-dst-ip-swap-persist': Create persist session after source IP and destination IP swap; 'use-src-ip-for-dst-persist': Use the source IP to create a destination persist session; 'use-dst-ip-for-src-persist': Use the destination IP to create source IP persist session; ", "format": "enum"}, "template-fix": {"description": "FIX template (FIX Template Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/fix"}, "snat-on-vip": {"default": 0, "optional": true, "type": "number", "description": "Enable source NAT traffic against VIP", "format": "flag"}, "bucket-count": {"optional": true, "minimum": 1, "type": "number", "maximum": 256, "format": "number"}, "use-default-if-no-server": {"default": 0, "optional": true, "type": "number", "description": "Use default forwarding if server selection failed", "format": "flag"}, "syn-cookie": {"default": 0, "optional": true, "type": "number", "description": "Enable syn-cookie", "format": "flag"}, "when-down": {"default": 0, "optional": true, "type": "number", "description": "Use alternate virtual port when down", "format": "flag"}, "template-udp": {"description": "L4 UDP Template (UDP Config Name)", "format": "string", "default": "default", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/udp"}, "aflex-scripts": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"aflex": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Bind aFleX Script to the Virtual Port (aFleX Script Name)", "format": "string"}, "optional": true}}]}, "acl-id-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"acl-id-seq-num": {"description": "Specify ACL precedence (sequence-number)", "minimum": 1, "type": "number", "maximum": 32, "format": "number"}, "acl-id": {"description": "ACL id VPORT", "format": "number", "maximum": 199, "$ref-list": ["/axapi/v3/access-list/standard", "/axapi/v3/access-list/extended"], "minimum": 1, "type": "number"}, "optional": true, "acl-id-src-nat-pool": {"description": "Policy based Source NAT (NAT Pool or Pool Group)", "format": "string", "minLength": 1, "$ref-list": ["/axapi/v3/ip/nat/pool", "/axapi/v3/ipv6/nat/pool", "/axapi/v3/ip/nat/pool-group", "/axapi/v3/ipv6/nat/pool-group"], "maxLength": 128, "type": "string"}}}]}, "alternate-port": {"description": "Alternate Virtual Port", "format": "flag", "default": 0, "optional": true, "modify-not-allowed": 1, "not": "range", "type": "number"}, "auto": {"default": 0, "optional": true, "type": "number", "description": "Configure auto NAT for the vport", "format": "flag"}, "view": {"description": "Specify a GSLB View (ID)", "format": "number", "type": "number", "maximum": 31, "minimum": 1, "optional": true}, "alternate-port-number": {"description": "Virtual Port", "format": "number", "type": "number", "maximum": 65534, "minimum": 0, "optional": true}, "port-number": {"description": "Port", "format": "number", "type": "number", "maximum": 65534, "minimum": 0, "optional": false}, "device-group": {"optional": true, "minimum": 1, "type": "number", "maximum": 64, "format": "number"}, "use-rcv-hop-for-resp": {"default": 0, "optional": true, "type": "number", "description": "Use receive hop for response to client", "format": "flag"}, "no-dest-nat": {"default": 0, "optional": true, "type": "number", "description": "Disable destination NAT", "format": "flag"}, "template-external-service": {"description": "External service template (external-service template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/external-service"}, "template-cache": {"description": "RAM caching template (Cache Template Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/cache"}, "extended-stats": {"default": 0, "optional": true, "type": "number", "description": "Enable extended statistics on virtual port", "format": "flag"}, "expand": {"default": 0, "optional": true, "type": "number", "description": "expand syn-cookie with timestamp and wscale", "format": "flag"}, "reset": {"default": 0, "optional": true, "type": "number", "description": "Send client reset when connection number over limit", "format": "flag"}, "req-fail": {"default": 0, "optional": true, "type": "number", "description": "Use alternate virtual port when L7 request fail", "format": "flag"}, "skip-rev-hash": {"default": 0, "optional": true, "type": "number", "description": "Skip rev tuple hash insertion", "format": "flag"}, "name": {"description": "SLB Virtual Service Name", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 127, "type": "string"}, "template-dblb": {"description": "DBLB Template (DBLB template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/dblb"}, "port-translation": {"default": 0, "optional": true, "type": "number", "description": "Enable port translation under no-dest-nat", "format": "flag"}, "template-smpp": {"description": "SMPP template", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/smpp"}, "clientip-sticky-nat": {"default": 0, "optional": true, "type": "number", "description": "Prefer to use same source NAT address for a client", "format": "flag"}, "template-persist-source-ip": {"description": "Source IP persistence (Source IP persistence template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string", "$ref": "/axapi/v3/slb/template/persist/source-ip"}, "serv-sel-fail": {"default": 0, "optional": true, "type": "number", "description": "Use alternate virtual port when server selection failure", "format": "flag"}, "template-diameter": {"description": "Diameter Template (diameter template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/diameter"}, "range": {"description": "Virtual Port range (Virtual Port range value)", "format": "number", "default": 0, "optional": true, "maximum": 254, "minimum": 0, "modify-not-allowed": 1, "not": "alternate-port", "type": "number"}, "when-down-protocol2": {"default": 0, "optional": true, "type": "number", "description": "Use alternate virtual port when down", "format": "flag"}, "def-selection-if-pref-failed": {"description": "'def-selection-if-pref-failed': Use default server selection method if prefer method failed; 'def-selection-if-pref-failed-disable': Stop using default server selection method if prefer method failed; ", "format": "enum", "default": "def-selection-if-pref-failed", "type": "string", "enum": ["def-selection-if-pref-failed", "def-selection-if-pref-failed-disable"], "optional": true}, "template-tcp-proxy": {"description": "TCP Proxy Template Name", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/tcp-proxy"}, "template-smtp": {"description": "SMTP Template (SMTP Config Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/smtp"}, "auth-cfg": {"type": "object", "properties": {"aaa-policy": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify AAA policy name to bind to the virtual port", "format": "string"}}}, "action": {"description": "'enable': Enable; 'disable': Disable; ", "format": "enum", "default": "enable", "type": "string", "enum": ["enable", "disable"], "optional": true}, "template-http": {"description": "HTTP Template (HTTP Config Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/http"}, "no-logging": {"default": 0, "optional": true, "type": "number", "description": "Do not log connection over limit event", "format": "flag"}, "template-server-ssl": {"description": "Server Side SSL Template (Server SSL Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/server-ssl"}, "alt-protocol2": {"optional": true, "enum": ["tcp"], "type": "string", "description": "'tcp': TCP LB service; ", "format": "enum"}, "alt-protocol1": {"optional": true, "enum": ["http"], "type": "string", "description": "'http': HTTP Port; ", "format": "enum"}, "message-switching": {"default": 0, "optional": true, "type": "number", "description": "Message switching", "format": "flag"}}}], "type": "array", "$ref": "/axapi/v3/slb/virtual-server/{name}/port/{port-number}+{protocol}"}, "stats-data-action": {"description": "'stats-data-enable': Enable statistical data collection for virtual server; 'stats-data-disable': Disable statistical data collection for virtual server; ", "format": "enum", "default": "stats-data-enable", "type": "string", "enum": ["stats-data-enable", "stats-data-disable"], "optional": true}, "acl-name": {"description": "Access List name (IPv4 Access List Name)", "format": "string", "minLength": 1, "modify-not-allowed": 1, "optional": true, "maxLength": 16, "type": "string", "$ref": "/axapi/v3/ip/access-list"}, "enable-disable-action": {"description": "'enable': Enable Virtual Server (default); 'disable': Disable Virtual Server; 'disable-when-all-ports-down': Disable Virtual Server when all member ports are down; 'disable-when-any-port-down': Disable Virtual Server when any member port is down; ", "format": "enum", "default": "enable", "type": "string", "enum": ["enable", "disable", "disable-when-all-ports-down", "disable-when-any-port-down"], "optional": true}, "ip-address": {"description": "IP Address", "format": "ipv4-address", "optional": true, "not-list": ["ipv6-address", "use-if-ip"], "modify-not-allowed": 1, "type": "string"}, "use-if-ip": {"description": "Use Interface IP", "format": "flag", "default": 0, "optional": true, "plat-pos-list": ["soft-ax"], "not-list": ["ipv6-address", "ip-address"], "type": "number"}, "vrid": {"description": "Join a vrrp group (Specify ha VRRP-A vrid)", "format": "number", "type": "number", "maximum": 31, "minimum": 1, "optional": true}, "template-virtual-server": {"description": "Virtual server template name", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/virtual-server"}, "policy": {"default": 0, "optional": true, "type": "number", "description": "Policy template", "format": "flag"}, "arp-disable": {"default": 0, "optional": true, "type": "number", "description": "Disable Respond to Virtual Server ARP request", "format": "flag"}, "description": {"description": "Create a description for VIP", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "redistribution-flagged": {"default": 0, "optional": true, "type": "number", "description": "Flag VIP for special redistribution handling", "format": "flag"}, "netmask": {"optional": true, "modify-not-allowed": 1, "type": "string", "description": "IP subnet mask", "format": "ipv4-netmask-brief"}, "acl-id": {"description": "acl id", "format": "number", "optional": true, "$ref-list": ["/axapi/v3/access-list/standard", "/axapi/v3/access-list/extended"], "maximum": 199, "minimum": 1, "modify-not-allowed": 1, "type": "number"}, "ipv6-acl": {"description": "ipv6 acl name", "format": "string", "minLength": 1, "modify-not-allowed": 1, "optional": true, "maxLength": 31, "type": "string", "$ref": "/axapi/v3/ipv6/access-list"}, "virtual-server": {"default": 0, "optional": true, "type": "number", "description": "Virtual server template", "format": "flag"}, "template-logging": {"description": "NAT Logging template name", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/ip/nat/template/logging"}, "extended-stats": {"default": 0, "optional": true, "type": "number", "description": "Enable extended statistics on virtual server", "format": "flag"}, "logging": {"default": 0, "optional": true, "type": "number", "description": "NAT Logging template", "format": "flag"}, "name": {"description": "SLB Virtual Server Name", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 127, "type": "string"}, "template-policy": {"description": "Policy template name", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/policy"}, "ipv6-address": {"description": "IPV6 address", "format": "ipv6-address", "optional": true, "not-list": ["ip-address", "use-if-ip"], "modify-not-allowed": 1, "type": "string"}, "ethernet": {"optional": true, "plat-pos-list": ["soft-ax"], "type": "number", "description": "Ethernet interface", "format": "interface"}}}], "type": "array", "$ref": "/axapi/v3/slb/virtual-server/{name}"}
    :param service_group_list: {"minItems": 1, "items": {"type": "service-group"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"conn-rate": {"description": "Dynamically enable stateless method by conn-rate (Rate to trigger stateless method(conn/sec))", "format": "number", "type": "number", "maximum": 1000000, "minimum": 1, "optional": true}, "reset-on-server-selection-fail": {"default": 0, "optional": true, "type": "number", "description": "Send reset to client if server selection fails", "format": "flag"}, "health-check-disable": {"description": "Disable health check", "format": "flag", "default": 0, "optional": true, "not": "health-check", "type": "number"}, "protocol": {"description": "'tcp': TCP LB service; 'udp': UDP LB service; ", "format": "enum", "type": "string", "enum": ["tcp", "udp"], "modify-not-allowed": 1, "optional": true}, "traffic-replication-mirror": {"default": 0, "optional": true, "type": "number", "description": "Mirror Bi-directional Packet", "format": "flag"}, "traffic-replication-mirror-ip-repl": {"default": 0, "optional": true, "type": "number", "description": "Replaces IP with server-IP", "format": "flag"}, "reset-priority-affinity": {"default": 0, "optional": true, "type": "number", "description": "Reset", "format": "flag"}, "min-active-member": {"description": "Minimum Active Member Per Priority (Minimum Active Member before Action)", "format": "number", "type": "number", "maximum": 63, "minimum": 1, "optional": true}, "member-list": {"minItems": 1, "items": {"type": "member"}, "uniqueItems": true, "array": [{"required": ["name", "port"], "properties": {"member-priority": {"description": "Priority of Port in the Group", "format": "number", "type": "number", "maximum": 16, "minimum": 1, "optional": true}, "name": {"description": "Member name", "format": "comp-string", "minLength": 1, "optional": false, "maxLength": 127, "type": "string", "$ref": "/axapi/v3/slb/server"}, "fqdn-name": {"description": "Server hostname - Not applicable if real server is already defined", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "member-template": {"description": "Real server port template (Real server port template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/port"}, "host": {"optional": true, "type": "string", "description": "IP Address - Not applicable if real server is already defined", "format": "ipv4-address"}, "member-state": {"description": "'enable': Enable member service port; 'disable': Disable member service port; ", "format": "enum", "default": "enable", "type": "string", "enum": ["enable", "disable"], "optional": true}, "server-ipv6-addr": {"optional": true, "type": "string", "description": "IPV6 Address - Not applicable if real server is already defined", "format": "ipv6-address"}, "port": {"description": "Port number", "format": "number", "default": 65534, "optional": false, "maximum": 65534, "minimum": 0, "type": "number", "$ref": "/axapi/v3/slb/server/port"}, "member-stats-data-disable": {"default": 0, "optional": true, "type": "number", "description": "Disable statistical data collection", "format": "flag"}}}], "type": "array", "$ref": "/axapi/v3/slb/service-group/{name}/member/{name}+{port}"}, "stats-data-action": {"description": "'stats-data-enable': Enable statistical data collection for service group; 'stats-data-disable': Disable statistical data collection for service group; ", "format": "enum", "default": "stats-data-enable", "type": "string", "enum": ["stats-data-enable", "stats-data-disable"], "optional": true}, "traffic-replication-mirror-da-repl": {"default": 0, "optional": true, "type": "number", "description": "Replace Destination MAC", "format": "flag"}, "rpt-ext-server": {"default": 0, "optional": true, "type": "number", "description": "Report top 10 fastest/slowest servers", "format": "flag"}, "template-port": {"description": "Port template (Port template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/port"}, "conn-rate-grace-period": {"description": "Define the grace period during transition (Define the grace period during transition(seconds))", "format": "number", "type": "number", "maximum": 600, "minimum": 1, "optional": true}, "l4-session-usage-duration": {"description": "Period that trigger condition consistently happens(seconds)", "format": "number", "type": "number", "maximum": 600, "minimum": 1, "optional": true}, "backup-server-event-log": {"default": 0, "optional": true, "type": "number", "description": "Send log info on back up server events", "format": "flag"}, "lc-method": {"description": "'least-connection': Least connection on server level; 'service-least-connection': Least connection on service port level; 'weighted-least-connection': Weighted least connection on server level; 'service-weighted-least-connection': Weighted least connection on service port level; ", "format": "enum", "optional": true, "enum": ["least-connection", "service-least-connection", "weighted-least-connection", "service-weighted-least-connection"], "not-list": ["lb-method", "stateless-lb-method"], "type": "string"}, "pseudo-round-robin": {"default": 0, "optional": true, "type": "number", "description": "PRR, select the oldest node for sub-select", "format": "flag"}, "l4-session-usage-revert-rate": {"description": "Usage to revert to statelful method", "format": "number", "type": "number", "maximum": 100, "minimum": 1, "optional": true}, "template-server": {"description": "Server template (Server template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/server"}, "stateless-lb-method": {"description": "'stateless-dst-ip-hash': Stateless load-balancing based on Dst IP and Dst port hash; 'stateless-per-pkt-round-robin': Stateless load-balancing using per-packet round-robin; 'stateless-src-dst-ip-hash': Stateless load-balancing based on IP and port hash for both Src and Dst; 'stateless-src-ip-hash': Stateless load-balancing based on Src IP and Src port hash; 'stateless-src-ip-only-hash': Stateless load-balancing based on only Src IP hash; ", "format": "enum", "optional": true, "enum": ["stateless-dst-ip-hash", "stateless-per-pkt-round-robin", "stateless-src-dst-ip-hash", "stateless-src-ip-hash", "stateless-src-ip-only-hash"], "not-list": ["lb-method", "lc-method"], "type": "string"}, "l4-session-revert-duration": {"description": "Period that revert condition consistently happens(seconds)", "format": "number", "type": "number", "maximum": 600, "minimum": 1, "optional": true}, "traffic-replication-mirror-sa-da-repl": {"default": 0, "optional": true, "type": "number", "description": "Replace Source MAC and Destination MAC", "format": "flag"}, "lb-method": {"description": "'dst-ip-hash': Load-balancing based on only Dst IP and Port hash; 'dst-ip-only-hash': Load-balancing based on only Dst IP hash; 'fastest-response': Fastest response time on service port level; 'least-request': Least request on service port level; 'src-ip-hash': Load-balancing based on only Src IP and Port hash; 'src-ip-only-hash': Load-balancing based on only Src IP hash; 'weighted-rr': Weighted round robin on server level; 'round-robin': Round robin on server level; 'round-robin-strict': Strict mode round robin on server level; ", "format": "enum", "default": "round-robin", "optional": true, "enum": ["dst-ip-hash", "dst-ip-only-hash", "fastest-response", "least-request", "src-ip-hash", "src-ip-only-hash", "weighted-rr", "round-robin", "round-robin-strict"], "not-list": ["lc-method", "stateless-lb-method"], "type": "string"}, "stateless-auto-switch": {"default": 0, "optional": true, "type": "number", "description": "Enable auto stateless method", "format": "flag"}, "min-active-member-action": {"optional": true, "enum": ["dynamic-priority", "skip-pri-set"], "type": "string", "description": "'dynamic-priority': dynamic change member priority to met the min-active-member requirement; 'skip-pri-set': Skip Current Priority Set If Min not met; ", "format": "enum"}, "l4-session-usage": {"description": "Dynamically enable stateless method by session usage (Usage to trigger stateless method)", "format": "number", "type": "number", "maximum": 100, "minimum": 1, "optional": true}, "extended-stats": {"default": 0, "optional": true, "type": "number", "description": "Enable extended statistics on service group", "format": "flag"}, "conn-rate-revert-duration": {"description": "Period that revert condition consistently happens(seconds)", "format": "number", "type": "number", "maximum": 600, "minimum": 1, "optional": true}, "conn-rate-log": {"default": 0, "optional": true, "type": "number", "description": "Send log if transition happens", "format": "flag"}, "reset": {"type": "object", "properties": {"auto-switch": {"default": 0, "type": "number", "description": "Reset auto stateless state", "format": "flag"}}}, "traffic-replication-mirror-sa-repl": {"default": 0, "optional": true, "type": "number", "description": "Replace Source MAC", "format": "flag"}, "report-delay": {"description": "Reporting frequency (in minutes)", "format": "number", "type": "number", "maximum": 7200, "minimum": 1, "optional": true}, "name": {"description": "SLB Service Name", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 127, "type": "string"}, "l4-session-usage-log": {"default": 0, "optional": true, "type": "number", "description": "Send log if transition happens", "format": "flag"}, "conn-rate-duration": {"description": "Period that trigger condition consistently happens(seconds)", "format": "number", "type": "number", "maximum": 600, "minimum": 1, "optional": true}, "l4-session-usage-grace-period": {"description": "Define the grace period during transition (Define the grace period during transition(seconds))", "format": "number", "type": "number", "maximum": 600, "minimum": 1, "optional": true}, "template-policy": {"description": "Policy template (Policy template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/policy"}, "stateless-lb-method2": {"optional": true, "enum": ["stateless-dst-ip-hash", "stateless-per-pkt-round-robin", "stateless-src-dst-ip-hash", "stateless-src-ip-hash", "stateless-src-ip-only-hash"], "type": "string", "description": "'stateless-dst-ip-hash': Stateless load-balancing based on Dst IP and Dst port hash; 'stateless-per-pkt-round-robin': Stateless load-balancing using per-packet round-robin; 'stateless-src-dst-ip-hash': Stateless load-balancing based on IP and port hash for both Src and Dst; 'stateless-src-ip-hash': Stateless load-balancing based on Src IP and Src port hash; 'stateless-src-ip-only-hash': Stateless load-balancing based on only Src IP hash; ", "format": "enum"}, "priorities": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"priority": {"description": "Priority option. Define different action for each priority node. (Priority in the Group)", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}, "priority-action": {"default": "proceed", "enum": ["drop", "drop-if-exceed-limit", "proceed", "reset", "reset-if-exceed-limit"], "type": "string", "description": "'drop': Drop request when all priority nodes fail; 'drop-if-exceed-limit': Drop request when connection over limit; 'proceed': Proceed to next priority when all priority nodes fail(default); 'reset': Send client reset when all priority nodes fail; 'reset-if-exceed-limit': Send client reset when connection over limit; ", "format": "enum"}, "optional": true}}]}, "sample-rsp-time": {"default": 0, "optional": true, "type": "number", "description": "sample server response time", "format": "flag"}, "top-fastest": {"default": 0, "optional": true, "type": "number", "description": "Report top 10 fastest servers", "format": "flag"}, "conn-revert-rate": {"description": "Rate to revert to statelful method (conn/sec)", "format": "number", "type": "number", "maximum": 1000000, "minimum": 1, "optional": true}, "priority-affinity": {"default": 0, "optional": true, "type": "number", "description": "Priority affinity. Persist to the same priority if possible.", "format": "flag"}, "top-slowest": {"default": 0, "optional": true, "type": "number", "description": "Report top 10 slowest servers", "format": "flag"}, "health-check": {"description": "Health Check (Monitor Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "not": "health-check-disable", "type": "string", "$ref": "/axapi/v3/health/monitor"}}}], "type": "array", "$ref": "/axapi/v3/slb/service-group/{name}"}
    :param server_list: {"minItems": 1, "items": {"type": "server"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"conn-resume": {"description": "Connection Resume (Connection Resume (min active conn before resume taking new conn))", "format": "number", "type": "number", "maximum": 1000000, "minimum": 1, "optional": true}, "health-check-disable": {"description": "Disable configured health check configuration", "format": "flag", "default": 0, "optional": true, "not": "health-check", "type": "number"}, "extended-stats": {"default": 0, "optional": true, "type": "number", "description": "Enable extended statistics on real server", "format": "flag"}, "stats-data-action": {"description": "'stats-data-enable': Enable statistical data collection for real server; 'stats-data-disable': Disable statistical data collection for real server; ", "format": "enum", "default": "stats-data-enable", "type": "string", "enum": ["stats-data-enable", "stats-data-disable"], "optional": true}, "name": {"description": "Server Name", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 127, "type": "string"}, "weight": {"description": "Weight for this Real Server (Connection Weight)", "format": "number", "default": 1, "optional": true, "maximum": 100, "minimum": 1, "type": "number"}, "fqdn-name": {"description": "Server hostname", "format": "string", "minLength": 1, "modify-not-allowed": 1, "optional": true, "maxLength": 63, "type": "string"}, "spoofing-cache": {"default": 0, "optional": true, "type": "number", "description": "This server is a spoofing cache", "format": "flag"}, "alternate-server": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"alternate-name": {"minLength": 1, "maxLength": 127, "type": "string", "description": "Alternate Name", "format": "string-rlx"}, "alternate": {"description": "Alternate Server (Alternate Server Number)", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}, "optional": true}}]}, "conn-limit": {"description": "Connection Limit", "format": "number", "default": 8000000, "optional": true, "maximum": 8000000, "minimum": 1, "type": "number"}, "external-ip": {"optional": true, "type": "string", "description": "External IP address for NAT of GSLB", "format": "ipv4-address"}, "host": {"optional": true, "modify-not-allowed": 1, "type": "string", "description": "IP Address", "format": "ipv4-address"}, "port-list": {"minItems": 1, "items": {"type": "port"}, "uniqueItems": true, "array": [{"required": ["port-number", "protocol"], "properties": {"conn-limit": {"description": "Connection Limit", "format": "number", "default": 8000000, "optional": true, "maximum": 8000000, "minimum": 1, "type": "number"}, "health-check-disable": {"description": "Disable health check", "format": "flag", "default": 0, "optional": true, "not-list": ["health-check", "health-check-follow-port"], "type": "number"}, "extended-stats": {"default": 0, "optional": true, "type": "number", "description": "Enable extended statistics on real server port", "format": "flag"}, "template-server-ssl": {"description": "Server side SSL template (Server side SSL Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/server-ssl"}, "weight": {"description": "Port Weight (Connection Weight)", "format": "number", "default": 1, "optional": true, "maximum": 100, "minimum": 1, "type": "number"}, "conn-resume": {"description": "Connection Resume", "format": "number", "type": "number", "maximum": 1000000, "minimum": 1, "optional": true}, "alternate-port": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"alternate-name": {"minLength": 1, "maxLength": 127, "type": "string", "description": "Alternate Name", "format": "string-rlx"}, "alternate-server-port": {"description": "Port (Alternate Server Port Value)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "alternate": {"description": "Alternate Server Number", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}, "optional": true}}]}, "no-logging": {"default": 0, "optional": true, "type": "number", "description": "Do not log connection over limit event", "format": "flag"}, "stats-data-action": {"description": "'stats-data-enable': Enable statistical data collection for real server port; 'stats-data-disable': Disable statistical data collection for real server port; ", "format": "enum", "default": "stats-data-enable", "type": "string", "enum": ["stats-data-enable", "stats-data-disable"], "optional": true}, "follow-port-protocol": {"optional": true, "enum": ["tcp", "udp"], "type": "string", "description": "'tcp': TCP Port; 'udp': UDP Port; ", "format": "enum"}, "port-number": {"description": "Port Number", "format": "number", "type": "number", "maximum": 65534, "minimum": 0, "optional": false}, "range": {"description": "Port range (Port range value - used for vip-to-rport-mapping)", "format": "number", "default": 0, "optional": true, "maximum": 254, "minimum": 0, "type": "number"}, "no-ssl": {"default": 0, "optional": true, "type": "number", "description": "No SSL", "format": "flag"}, "auth-cfg": {"type": "object", "properties": {"service-principal-name": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Service Principal Name (Kerberos principal name)", "format": "string-rlx"}}}, "action": {"description": "'enable': enable; 'disable': disable; ", "format": "enum", "default": "enable", "type": "string", "enum": ["enable", "disable"], "optional": true}, "protocol": {"optional": false, "enum": ["tcp", "udp"], "type": "string", "description": "'tcp': TCP Port; 'udp': UDP Port; ", "format": "enum"}, "health-check-follow-port": {"description": "Specify which port to follow for health status (Port Number)", "format": "number", "optional": true, "not-list": ["health-check", "health-check-disable"], "maximum": 65534, "minimum": 1, "type": "number"}, "health-check": {"description": "Health Check (Monitor Name)", "format": "string", "minLength": 1, "not-list": ["health-check-follow-port", "health-check-disable"], "optional": true, "maxLength": 31, "type": "string", "$ref": "/axapi/v3/health/monitor"}, "template-port": {"description": "Port template (Port template name)", "format": "string", "default": "default", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/port"}}}], "type": "array", "$ref": "/axapi/v3/slb/server/{name}/port/{port-number}+{protocol}"}, "slow-start": {"default": 0, "optional": true, "type": "number", "description": "Slowly ramp up the connection number after server is up (start from 128, then double every 10 sec till 4096)", "format": "flag"}, "ipv6": {"optional": true, "type": "string", "description": "IPv6 address Mapping of GSLB", "format": "ipv6-address"}, "action": {"description": "'enable': Enable this Real Server; 'disable': Disable this Real Server; ", "format": "enum", "default": "enable", "type": "string", "enum": ["enable", "disable"], "optional": true}, "template-server": {"description": "Server template (Server template name)", "format": "string", "default": "default", "minLength": 1, "optional": true, "maxLength": 32, "type": "string", "$ref": "/axapi/v3/slb/template/server"}, "server-ipv6-addr": {"optional": true, "modify-not-allowed": 1, "type": "string", "description": "IPV6 address", "format": "ipv6-address"}, "health-check": {"description": "Health Check Monitor (Health monitor name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "not": "health-check-disable", "type": "string", "$ref": "/axapi/v3/health/monitor"}, "no-logging": {"default": 0, "optional": true, "type": "number", "description": "Do not log connection over limit event", "format": "flag"}}}], "type": "array", "$ref": "/axapi/v3/slb/server/{name}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "slb"
        self.a10_url="/axapi/v3/slb"
        self.DeviceProxy = ""
        self.resource_usage = {}
        self.virtual_server_list = []
        self.ssl_expire_check = {}
        self.service_group_list = []
        self.server_list = []
        self.common = {}
        self.template = {}
        self.transparent_tcp_template = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


