from a10sdk.common.A10BaseClass import A10BaseClass


class Template(A10BaseClass):
    
    """Class Description::
    Define an SLB template.

    Class template supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param logging_list: {"minItems": 1, "items": {"type": "logging"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"name": {"description": "Logging Template Name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "format": {"description": "Specfiy a format string for web logging (format string(less than 250 characters) for web logging)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 250, "type": "string"}, "local-logging": {"description": "1 to enable local logging", "format": "number", "type": "number", "maximum": 1, "minimum": 0, "optional": true}, "keep-end": {"description": "Number of unmasked characters at the end (default: 0)", "format": "number", "type": "number", "maximum": 65535, "minimum": 0, "optional": true}, "mask": {"description": "Character to mask the matched pattern (default: X)", "format": "string", "minLength": 1, "optional": true, "maxLength": 1, "type": "string"}, "keep-start": {"description": "Number of unmasked characters at the beginning (default: 0)", "format": "number", "type": "number", "maximum": 65535, "minimum": 0, "optional": true}, "service-group": {"description": "Bind a Service Group to the logging template (Service Group Name)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 127, "type": "string", "$ref": "/axapi/v3/slb/service-group"}, "pcre-mask": {"description": "Mask matched PCRE pattern in the log", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "tcp-proxy": {"description": "TCP proxy template (TCP Proxy Config name)", "format": "string", "default": "default", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/slb/template/logging/{name}"}
    :param cache_list: {"minItems": 1, "items": {"type": "cache"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"accept-reload-req": {"default": 0, "optional": true, "type": "number", "description": "Accept reload requests via cache-control directives in HTTP headers", "format": "flag"}, "name": {"description": "Specify cache template name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "age": {"description": "Specify duration in seconds cached content valid, default is 3600 seconds (seconds that the cached content is valid (default 3600 seconds))", "format": "number", "default": 3600, "optional": true, "maximum": 999999, "minimum": 1, "type": "number"}, "disable-insert-via": {"default": 0, "optional": true, "type": "number", "description": "Disable insertion of via header in response served from RAM cache", "format": "flag"}, "disable-insert-age": {"default": 0, "optional": true, "type": "number", "description": "Disable insertion of age header in response served from RAM cache", "format": "flag"}, "local-uri-policy": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "local-uri": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify Local URI for caching (Specify URI pattern that the policy should be applied to, maximum 63 charaters)", "format": "string-rlx"}}}]}, "replacement-policy": {"description": "'LFU': LFU; ", "format": "enum", "default": "LFU", "type": "string", "enum": ["LFU"], "optional": true}, "min-content-size": {"description": "Minimum size (bytes) of response that can be cached - default 512", "format": "number", "default": 512, "optional": true, "maximum": 268435455, "minimum": 0, "type": "number"}, "max-content-size": {"description": "Maximum size (bytes) of response that can be cached - default 81920 (80KB)", "format": "number", "default": 81920, "optional": true, "maximum": 268435455, "minimum": 0, "type": "number"}, "max-cache-size": {"description": "Specify maximum cache size in megabytes, default is 80MB (RAM cache size in megabytes (default 80MB))", "format": "number", "default": 80, "optional": true, "maximum": 4096, "minimum": 1, "type": "number"}, "logging": {"description": "Specify logging template (Logging Config name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/logging"}, "remove-cookies": {"default": 0, "optional": true, "type": "number", "description": "Remove cookies in response and cache", "format": "flag"}, "verify-host": {"default": 0, "optional": true, "type": "number", "description": "Verify request using host before sending response from RAM cache", "format": "flag"}, "default-policy-nocache": {"default": 0, "optional": true, "type": "number", "description": "Specify default policy to be to not cache", "format": "flag"}, "uri-policy": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"cache-action": {"enum": ["cache", "nocache"], "type": "string", "description": "'cache': Specify if certain URIs should be cached; 'nocache': Specify if certain URIs should not be cached; ", "format": "enum"}, "invalidate": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Specify if URI should invalidate chache entries matching pattern (pattern that would match entries to be invalidated (64 chars max))", "format": "string"}, "uri": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify URI for cache policy (Specify URI pattern that the policy should be applied to, maximum 63 charaters)", "format": "string-rlx"}, "optional": true, "cache-value": {"description": "Specify seconds that content should be cached, default is age specified in cache template", "minimum": 1, "type": "number", "maximum": 999999, "format": "number"}}}]}}}], "type": "array", "$ref": "/axapi/v3/slb/template/cache/{name}"}
    :param port_list: {"minItems": 1, "items": {"type": "port"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"health-check-disable": {"description": "Disable configured health check configuration", "format": "flag", "default": 0, "optional": true, "not": "health-check", "type": "number"}, "stats-data-action": {"description": "'stats-data-enable': Enable statistical data collection for real server port; 'stats-data-disable': Disable statistical data collection for real server port; ", "format": "enum", "default": "stats-data-enable", "type": "string", "enum": ["stats-data-enable", "stats-data-disable"], "optional": true}, "dest-nat": {"default": 0, "optional": true, "type": "number", "description": "Destination NAT", "format": "flag"}, "request-rate-limit": {"description": "Request rate limit", "format": "number", "type": "number", "maximum": 1048575, "minimum": 1, "optional": true}, "dynamic-member-priority": {"description": "Set dynamic member's priority (Initial priority (default is 16))", "format": "number", "default": 16, "optional": true, "maximum": 16, "minimum": 1, "type": "number"}, "till": {"description": "Slow start ends when slow start connection limit reaches a number (default 4096) (Slow start ends when connection limit reaches this number)", "format": "number", "default": 4096, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}, "slow-start": {"default": 0, "optional": true, "type": "number", "description": "Slowly ramp up the connection number after port is up", "format": "flag"}, "decrement": {"default": 0, "optional": true, "type": "number", "description": "Decrease dynamic member's priority after every round of DNS query", "format": "flag"}, "conn-limit": {"description": "Connection limit", "format": "number", "type": "number", "maximum": 8000000, "minimum": 1, "optional": true}, "retry": {"description": "Maximum retry times before reassign this connection to another server/port (default is 2) (The maximum retry number)", "format": "number", "default": 2, "optional": true, "maximum": 7, "minimum": 0, "type": "number"}, "weight": {"description": "Weight (port weight)", "format": "number", "type": "number", "maximum": 100, "minimum": 1, "optional": true}, "inband-health-check": {"default": 0, "optional": true, "type": "number", "description": "Use inband traffic to detect port's health status", "format": "flag"}, "initial-slow-start": {"description": "Initial slow start connection limit (default 128)", "format": "number", "default": 128, "optional": true, "maximum": 4095, "minimum": 1, "type": "number"}, "rate-interval": {"description": "'100ms': Use 100 ms as sampling interval; 'second': Use 1 second as sampling interval; ", "format": "enum", "default": "second", "type": "string", "enum": ["100ms", "second"], "optional": true}, "no-ssl": {"default": 0, "optional": true, "type": "number", "description": "No SSL", "format": "flag"}, "request-rate-interval": {"description": "'100ms': Use 100 ms as sampling interval; 'second': Use 1 second as sampling interval; ", "format": "enum", "default": "second", "type": "string", "enum": ["100ms", "second"], "optional": true}, "add": {"description": "Slow start connection limit add by a number every interval (Add by this number every interval)", "format": "number", "optional": true, "maximum": 4095, "minimum": 1, "not": "times", "type": "number"}, "down-grace-period": {"description": "Port down grace period", "format": "number", "type": "number", "maximum": 86400, "minimum": 1, "optional": true}, "resume": {"description": "Resume accepting new connection after connection number drops below threshold (Connection resume threshold)", "format": "number", "type": "number", "maximum": 1048575, "minimum": 1, "optional": true}, "dscp": {"description": "Differentiated Services Code Point (DSCP to Real Server IP Mapping Value)", "format": "number", "type": "number", "maximum": 63, "minimum": 1, "optional": true}, "every": {"description": "Slow start connection limit increment interval (default 10)", "format": "number", "default": 10, "optional": true, "maximum": 60, "minimum": 1, "type": "number"}, "conn-limit-no-logging": {"default": 0, "optional": true, "type": "number", "description": "Do not log connection over limit event", "format": "flag"}, "extended-stats": {"default": 0, "optional": true, "type": "number", "description": "Enable extended statistics on real server port", "format": "flag"}, "decrement-val": {"description": "Decrease after every round of DNS query (default is 0)", "format": "number", "default": 0, "optional": true, "maximum": 7, "minimum": 0, "type": "number"}, "reset": {"default": 0, "optional": true, "type": "number", "description": "Send client reset when connection rate over limit", "format": "flag"}, "conn-rate-limit-no-logging": {"default": 0, "optional": true, "type": "number", "description": "Do not log connection over limit event", "format": "flag"}, "name": {"description": "Port template name", "format": "string", "default": "default", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "times": {"description": "Slow start connection limit multiply by a number every interval (default 2) (Multiply by this number every interval)", "format": "number", "default": 2, "optional": true, "maximum": 10, "minimum": 2, "not": "add", "type": "number"}, "request-rate-no-logging": {"default": 0, "optional": true, "type": "number", "description": "Do not log connection over limit event", "format": "flag"}, "conn-rate-limit": {"description": "Connection rate limit", "format": "number", "type": "number", "maximum": 1048575, "minimum": 1, "optional": true}, "source-nat": {"description": "Source NAT (IP NAT Pool or pool group name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}, "reassign": {"description": "Maximum reassign times before declear the server/port down (default is 25) (The maximum reassign number)", "format": "number", "default": 25, "optional": true, "maximum": 255, "minimum": 0, "type": "number"}, "health-check": {"description": "Health Check Monitor (Health monitor name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "not": "health-check-disable", "type": "string", "$ref": "/axapi/v3/health/monitor"}}}], "type": "array", "$ref": "/axapi/v3/slb/template/port/{name}"}
    :param connection_reuse_list: {"minItems": 1, "items": {"type": "connection-reuse"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"preopen": {"default": 0, "optional": true, "type": "number", "description": "Preopen server connection", "format": "flag"}, "name": {"description": "Connection Reuse Template Name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "keep-alive-conn": {"default": 0, "optional": true, "type": "number", "description": "Keep a number of server connections open", "format": "flag"}, "timeout": {"description": "Timeout in seconds. Multiple of 60 (def 2400)", "format": "number", "default": 2400, "optional": true, "maximum": 3600, "minimum": 60, "type": "number"}, "num-conn-per-port": {"description": "Connections per Server Port (default 100)", "format": "number", "default": 100, "optional": true, "maximum": 1024, "minimum": 1, "type": "number"}, "limit-per-server": {"description": "Max Server Connections allowed (Connections per Server Port (default 1000))", "format": "number", "default": 1000, "optional": true, "maximum": 65535, "minimum": 0, "type": "number"}}}], "type": "array", "$ref": "/axapi/v3/slb/template/connection-reuse/{name}"}
    :param smpp_list: {"minItems": 1, "items": {"type": "smpp"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"name": {"description": "SMPP Template Name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "server-enquire-link": {"default": 0, "optional": true, "type": "number", "description": "Send server ENQUIRE_LINK packet for every persist connection when enable conn-reuse", "format": "flag"}, "server-selection-per-request": {"default": 0, "optional": true, "type": "number", "description": "Force server selection on every SMPP request when enable conn-reuse", "format": "flag"}, "client-enquire-link": {"default": 0, "optional": true, "type": "number", "description": "Respond client ENQUIRE_LINK packet directly instead of forwarding to server", "format": "flag"}, "server-enquire-link-val": {"description": "Set interval of keep-alive packet for each persistent connection (second, default is 30)", "format": "number", "default": 30, "optional": true, "maximum": 300, "minimum": 5, "type": "number"}, "user": {"description": "Configure the user to bind (The name used to bind)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "password": {"description": "Configure the password used to bind", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/slb/template/smpp/{name}"}
    :param smtp_list: {"minItems": 1, "items": {"type": "smtp"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"name": {"description": "SMTP Template Name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "starttls": {"description": "'disabled': Disable STARTTLS; 'optional': STARTTLS is optional requirement; 'enforced': Must issue STARTTLS command before mail transaction; ", "format": "enum", "default": "disabled", "type": "string", "enum": ["disabled", "optional", "enforced"], "optional": true}, "server-domain": {"description": "Config the domain of the email servers (Server's domain, default is \"mail-server-domain\")", "format": "string-rlx", "default": "mail-server-domain", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}, "client-domain-switching": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"service-group": {"description": "Select service group (Service group name)", "format": "string-rlx", "minLength": 1, "maxLength": 127, "type": "string", "$ref": "/axapi/v3/slb/service-group"}, "match-string": {"minLength": 1, "maxLength": 31, "type": "string", "description": "Domain name string", "format": "string-rlx"}, "optional": true, "switching-type": {"enum": ["contains", "ends-with", "starts-with"], "type": "string", "description": "'contains': Specify domain name string if domain contains another string; 'ends-with': Specify domain name string if domain ends with another string; 'starts-with': Specify domain string if domain starts with another string; ", "format": "enum"}}}]}, "command-disable": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "disable-type": {"enum": ["expn", "turn", "vrfy"], "type": "string", "description": "'expn': Disable SMTP EXPN commands; 'turn': Disable SMTP TURN commands; 'vrfy': Disable SMTP VRFY commands; ", "format": "enum"}}}]}, "service-ready-msg": {"description": "Set SMTP service ready message (SMTP service ready message, default is \"ESMTP mail service ready\")", "format": "string-rlx", "default": "ESMTP mail service ready", "minLength": 1, "optional": true, "maxLength": 127, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/slb/template/smtp/{name}"}
    :param external_service_list: {"minItems": 1, "items": {"type": "external-service"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"name": {"description": "External Service Template Name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "source-ip": {"description": "Source IP persistence template (Source IP persistence template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/persist/source-ip"}, "service-group": {"description": "Bind a Service Group to the template (Service Group Name)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 127, "type": "string", "$ref": "/axapi/v3/slb/service-group"}, "bypass-ip-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "bypass-ip": {"type": "string", "description": "ip address to bypass external service", "format": "ipv4-address"}, "mask": {"type": "string", "description": "IP prefix mask", "format": "ipv4-netmask"}}}]}, "failure-action": {"optional": true, "enum": ["continue", "drop", "reset"], "type": "string", "description": "'continue': Continue; 'drop': Drop; 'reset': Reset; ", "format": "enum"}, "timeout": {"description": "timeout value 1 - 200 in units of 200ms, default is 5 (default is 1000ms) (1 - 200 in units of 200ms, default is 5 (1000ms))", "format": "number", "default": 5, "optional": true, "maximum": 200, "minimum": 1, "type": "number"}, "tcp-proxy": {"description": "TCP proxy template (TCP proxy template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/tcp-proxy"}, "action": {"description": "'continue': Continue; 'drop': Drop; 'reset': Reset; ", "format": "enum", "default": "continue", "type": "string", "enum": ["continue", "drop", "reset"], "optional": true}, "type": {"description": "'skyfire-icap': Skyfire ICAP service; 'url-filter': URL filtering service; ", "format": "enum", "default": "url-filter", "type": "string", "enum": ["skyfire-icap", "url-filter"], "optional": true}}}], "type": "array", "$ref": "/axapi/v3/slb/template/external-service/{name}"}
    :param tcp_list: {"minItems": 1, "items": {"type": "tcp"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"initial-window-size": {"description": "Set the initial window size (number)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}, "alive-if-active": {"default": 0, "optional": true, "type": "number", "description": "keep connection alive if active traffic", "format": "flag"}, "qos": {"description": "QOS level (number)", "format": "number", "type": "number", "maximum": 63, "minimum": 1, "optional": true}, "name": {"description": "Fast TCP Template Name", "format": "string", "default": "default", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "reset-fwd": {"default": 0, "optional": true, "type": "number", "description": "send reset to server if error happens", "format": "flag"}, "half-open-idle-timeout": {"description": "TCP Half Open Idle Timeout (sec), default off (half open idle timeout in second, default off)", "format": "number", "type": "number", "maximum": 60, "minimum": 1, "optional": true}, "idle-timeout": {"description": "Idle Timeout value (default 120 seconds) (idle timeout in second, default 120)", "format": "number", "type": "number", "maximum": 2097151, "minimum": 1, "optional": true}, "force-delete-timeout": {"description": "The maximum time that a session can stay in the system before being delete (number (second))", "format": "number", "optional": true, "maximum": 31, "minimum": 1, "not": "force-delete-timeout-100ms", "type": "number"}, "lan-fast-ack": {"default": 0, "optional": true, "type": "number", "description": "Enable fast TCP ack on LAN", "format": "flag"}, "insert-client-ip": {"default": 0, "optional": true, "type": "number", "description": "Insert client ip into TCP option", "format": "flag"}, "reset-rev": {"default": 0, "optional": true, "type": "number", "description": "send reset to client if error happens", "format": "flag"}, "force-delete-timeout-100ms": {"description": "The maximum time that a session can stay in the system before being delete (number in 100ms)", "format": "number", "optional": true, "maximum": 31, "minimum": 1, "not": "force-delete-timeout", "type": "number"}, "half-close-idle-timeout": {"description": "TCP Half Close Idle Timeout (sec), default off (half close idle timeout in second, default off)", "format": "number", "type": "number", "maximum": 120, "minimum": 60, "optional": true}}}], "type": "array", "$ref": "/axapi/v3/slb/template/tcp/{name}"}
    :param diameter_list: {"minItems": 1, "items": {"type": "diameter"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"avp-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"int32": {"not-list": ["int64", "string"], "type": "number", "description": "32 bits integer", "format": "number"}, "mandatory": {"default": 0, "type": "number", "description": "mandatory avp", "format": "flag"}, "string": {"description": "String (string name, max length 127 bytes)", "format": "string", "minLength": 1, "not-list": ["int32", "int64"], "maxLength": 128, "type": "string"}, "avp": {"type": "number", "description": "customize avps for cer to the server (avp number)", "format": "number"}, "int64": {"not-list": ["int32", "string"], "type": "number", "description": "64 bits integer", "format": "number"}, "optional": true}}]}, "service-group-name": {"description": "service group name, this is the service group that the message needs to be copied to", "format": "string", "minLength": 1, "optional": true, "maxLength": 127, "type": "string"}, "name": {"description": "diameter template Name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "dwr-time": {"description": "dwr health-check timer interval (in 100 milli second unit, default is 0)", "format": "number", "default": 0, "optional": true, "maximum": 2147483647, "minimum": 0, "type": "number"}, "avp-string": {"description": "pattern to be matched in the avp string name, max length 127 bytes", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}, "idle-timeout": {"description": " user sesison idle timeout (in minutes, default is 5)", "format": "number", "default": 5, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}, "avp-code": {"description": "avp code", "format": "number", "type": "number", "maximum": 2147483647, "minimum": 1, "optional": true}, "duplicate": {"default": 0, "optional": true, "type": "number", "description": "copy a message to a different server", "format": "flag"}, "message-code-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "message-code": {"minimum": 0, "type": "number", "maximum": 2147483647, "format": "number"}}}]}, "origin-realm": {"description": "origin-realm name avp", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}, "origin-host": {"description": "origin-host name avp", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}, "customize-cea": {"default": 0, "optional": true, "type": "number", "description": "customizing cea response", "format": "flag"}, "multiple-origin-host": {"default": 0, "optional": true, "type": "number", "description": "allowing multiple origin-host to a single server", "format": "flag"}, "product-name": {"description": "product name avp", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}, "session-age": {"description": "user session age allowed (default 10), this is not idle-time (in minutes)", "format": "number", "default": 10, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}, "vendor-id": {"description": "vendor-id avp (Vendon Id)", "format": "number", "type": "number", "maximum": 2147483647, "minimum": 0, "optional": true}}}], "type": "array", "$ref": "/axapi/v3/slb/template/diameter/{name}"}
    :param udp_list: {"minItems": 1, "items": {"type": "udp"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"short": {"description": "Short lived session", "format": "flag", "default": 0, "optional": true, "not": "immediate", "type": "number"}, "qos": {"description": "QOS level (number)", "format": "number", "type": "number", "maximum": 63, "minimum": 1, "optional": true}, "name": {"description": "Fast UDP Template Name", "format": "string", "default": "default", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "age": {"optional": true, "minimum": 1, "type": "number", "maximum": 31, "format": "number"}, "stateless-conn-timeout": {"description": "Stateless Current Connection Timeout value (5 - 120 seconds) (idle timeout in second, default 120)", "format": "number", "type": "number", "maximum": 120, "minimum": 5, "optional": true}, "idle-timeout": {"description": "Idle Timeout value (default 120 seconds) (idle timeout in second, default 120)", "format": "number", "default": 120, "optional": true, "maximum": 2097151, "minimum": 1, "type": "number"}, "re-select-if-server-down": {"default": 0, "optional": true, "type": "number", "description": "re-select another server if service port is down", "format": "flag"}, "immediate": {"description": "Immediate Removal after Transaction", "format": "flag", "default": 0, "optional": true, "not": "short", "type": "number"}}}], "type": "array", "$ref": "/axapi/v3/slb/template/udp/{name}"}
    :param http_policy_list: {"minItems": 1, "items": {"type": "http-policy"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"geo-location-match": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"geo-location": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Geolocation name", "format": "string"}, "geo-location-service-group": {"description": "Service Group to be used (Service Group Name)", "format": "string-rlx", "minLength": 1, "maxLength": 127, "type": "string", "$ref": "/axapi/v3/slb/service-group"}, "optional": true, "geo-location-template": {"enum": ["waf"], "type": "string", "description": "'waf': waf;  (WAF template to be used)", "format": "enum"}, "geo-location-template-name": {"description": "WAF template to be used (Template Name)", "format": "string", "minLength": 1, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/waf/template"}}}]}, "name": {"description": "http-policy template name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "http-policy-match": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "match-string": {"minLength": 1, "maxLength": 128, "type": "string", "description": "URL String", "format": "string-rlx"}, "template-name": {"description": "WAF template to be used (Template Name)", "format": "string", "minLength": 1, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/waf/template"}, "service-group": {"description": "Service Group to be used (Service Group Name)", "format": "string", "minLength": 1, "maxLength": 127, "type": "string", "$ref": "/axapi/v3/slb/service-group"}, "template": {"enum": ["waf"], "type": "string", "description": "'waf': waf;  (WAF template to be used)", "format": "enum"}, "type": {"enum": ["cookie", "host", "url"], "type": "string", "description": "'cookie': cookie value match; 'host': hostname match; 'url': URL match; ", "format": "enum"}, "match-type": {"enum": ["contains", "ends-with", "equals", "starts-with"], "type": "string", "description": "'contains': Select service group if URL string contains another string; 'ends-with': Select service group if URL string ends with another string; 'equals': Select service group if URL string equals another string; 'starts-with': Select service group if URL string starts with another string; ", "format": "enum"}}}]}, "cookie-name": {"description": "name of cookie to match (Cookie Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/slb/template/http-policy/{name}"}
    :param client_ssl_list: {"minItems": 1, "items": {"type": "client-ssl"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"chain-cert": {"description": "Chain Certificate (Chain Certificate Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 255, "type": "string"}, "session-cache-timeout": {"description": "Session Cache Timeout (Timeout value, in seconds)", "format": "number", "type": "number", "maximum": 604800, "minimum": 0, "optional": true}, "ocspst-sg": {"description": "Specify authentication service group", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 127, "not": "ocspst-srvr", "type": "string", "$ref": "/axapi/v3/aam/authentication/service-group"}, "auth-username": {"description": "Specify the Username Field in the Client Certificate(If multi-fields are specificed, prior one has higher priority)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "authorization": {"default": 0, "optional": true, "type": "number", "description": "Specify LDAP server for client SSL authorizaiton", "format": "flag"}, "ocspst-sg-hours": {"description": "Specify update period, in hours", "format": "number", "optional": true, "not-list": ["ocspst-sg-days", "ocspst-sg-minutes"], "maximum": 44640, "minimum": 1, "type": "number"}, "ocspst-sg-days": {"description": "Specify update period, in days", "format": "number", "optional": true, "not-list": ["ocspst-sg-hours", "ocspst-sg-minutes"], "maximum": 31, "minimum": 1, "type": "number"}, "ldap-search-filter": {"description": "Specify LDAP search filter", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 255, "type": "string"}, "authen-name": {"description": "Specify authorization LDAP server name", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "not": "auth-sg", "type": "string", "$ref": "/axapi/v3/aam/authentication/server/ldap"}, "ocsp-stapling": {"default": 0, "optional": true, "type": "number", "description": "Config OCSP stapling support", "format": "flag"}, "forward-encrypted": {"optional": true, "type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}, "ocspst-srvr": {"description": "Specify OCSP authentication server", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "not": "ocspst-sg", "type": "string", "$ref": "/axapi/v3/aam/authentication/server/ocsp"}, "class-list-name": {"description": "Class List Name", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "forward-proxy-ca-cert": {"description": "CA Certificate for forward proxy (SSL forward proxy CA Certificate Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 255, "type": "string"}, "ocspst-sg-timeout": {"description": "Specify retry timeout (Default is 30 mins)", "format": "number", "type": "number", "maximum": 44640, "minimum": 1, "optional": true}, "ssl-false-start-disable": {"default": 0, "optional": true, "type": "number", "description": "disable SSL False Start", "format": "flag"}, "key-passphrase": {"description": "Password Phrase", "format": "password", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "template-cipher": {"description": "Cipher Template (Cipher Config Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "ocspst-srvr-minutes": {"description": "Specify update period, in minutes", "format": "number", "optional": true, "not-list": ["ocspst-srvr-days", "ocspst-srvr-hours"], "maximum": 60, "minimum": 1, "type": "number"}, "auth-sg": {"description": "Specify authorization LDAP service group", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 127, "not": "authen-name", "type": "string", "$ref": "/axapi/v3/aam/authentication/service-group"}, "key-encrypted": {"optional": true, "type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}, "equals-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "equals": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Forward proxy bypass if SNI string equals another string", "format": "string-rlx"}}}]}, "session-ticket-lifetime": {"optional": true, "type": "number", "description": "Session ticket lieftime in seconds from stateless session resumption (Lifetime value in seconds)", "format": "number"}, "forward-passphrase": {"description": "Password Phrase", "format": "password", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "ldap-base-dn-from-cert": {"default": 0, "optional": true, "type": "number", "description": "Use Subject DN as LDAP search base DN", "format": "flag"}, "contains-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"contains": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Forward proxy bypass if SNI string contains another string", "format": "string-rlx"}, "optional": true}}]}, "forward-proxy-ca-key": {"description": "CA Private Key for forward proxy (SSL forward proxy CA Key Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 255, "type": "string"}, "ocspst-srvr-days": {"description": "Specify update period, in days", "format": "number", "optional": true, "not-list": ["ocspst-srvr-hours", "ocspst-srvr-minutes"], "maximum": 31, "minimum": 1, "type": "number"}, "session-cache-size": {"description": "Session Cache Size (Specify 0 to disable Session ID reuse.)", "format": "number", "type": "number", "maximum": 8000000, "minimum": 0, "optional": true}, "client-certificate": {"description": "'Ignore': Don't request client certificate; 'Require': Require client certificate; 'Request': Request client certificate; ", "format": "enum", "default": "Ignore", "type": "string", "enum": ["Ignore", "Require", "Request"], "optional": true}, "ends-with-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ends-with": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Forward proxy bypass if SNI string ends with another string", "format": "string-rlx"}, "optional": true}}]}, "ocspst-ca-cert": {"description": "CA certificate", "format": "string", "minLength": 1, "optional": true, "maxLength": 255, "type": "string"}, "ocspst-ocsp": {"default": 0, "optional": true, "type": "number", "description": "Specify OCSP Authentication", "format": "flag"}, "forward-proxy-enable": {"default": 0, "optional": true, "type": "number", "description": "Enable SSL forward proxy", "format": "flag"}, "key": {"description": "Server Private Key (Key Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 255, "type": "string"}, "sslv2-bypass-service-group": {"description": "Service Group for Bypass SSLV2 (Service Group Name)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 127, "type": "string", "$ref": "/axapi/v3/slb/service-group"}, "server-name-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"server-name": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Server name indication in Client hello extension (Server name String)", "format": "string"}, "server-key": {"minLength": 1, "maxLength": 255, "type": "string", "description": "Server Private Key associated to SNI (Server Private Key Name)", "format": "string"}, "server-passphrase": {"minLength": 1, "maxLength": 63, "type": "string", "description": "help Password Phrase", "format": "password"}, "optional": true, "server-encrypted": {"type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}, "server-cert": {"minLength": 1, "maxLength": 255, "type": "string", "description": "Server Certificate associated to SNI (Server Certificate Name)", "format": "string"}}}]}, "auth-sg-filter": {"description": "Specify LDAP search filter", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 255, "type": "string"}, "ca-certs": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ca-cert": {"minLength": 1, "maxLength": 255, "type": "string", "description": "CA Certificate (CA Certificate Name)", "format": "string"}, "client-ocsp": {"default": 0, "type": "number", "description": "Specify ocsp authentication server(s) for client certificate verification", "format": "flag"}, "client-ocsp-sg": {"description": "Specify service-group (Service group name)", "format": "string-rlx", "minLength": 1, "maxLength": 127, "type": "string", "$ref": "/axapi/v3/aam/authentication/service-group"}, "optional": true, "client-ocsp-srvr": {"description": "Specify authentication server", "format": "string-rlx", "minLength": 1, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/aam/authentication/server/ocsp"}}}]}, "disable-sslv3": {"default": 0, "optional": true, "type": "number", "description": "Reject Client requests for SSL version 3", "format": "flag"}, "ocspst-srvr-timeout": {"description": "Specify retry timeout (Default is 30 mins)", "format": "number", "type": "number", "maximum": 44640, "minimum": 1, "optional": true}, "name": {"description": "Client SSL Template Name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "auth-sg-dn": {"default": 0, "optional": true, "type": "number", "description": "Use Subject DN as LDAP search base DN", "format": "flag"}, "ocspst-sg-period": {"default": 0, "optional": true, "type": "number", "description": "Specify certificate status update period (Default is 1 hour)", "format": "flag"}, "ocspst-srvr-hours": {"description": "Specify update period, in hours", "format": "number", "optional": true, "not-list": ["ocspst-srvr-days", "ocspst-srvr-minutes"], "maximum": 44640, "minimum": 1, "type": "number"}, "cert": {"description": "Server Certificate (Certificate Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 255, "type": "string"}, "ocspst-srvr-period": {"default": 0, "optional": true, "type": "number", "description": "Specify certificate status update period (Default is 1 hour)", "format": "flag"}, "crl": {"description": "Certificate Revocation Lists (Certificate Revocation Lists file name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 255, "type": "string"}, "case-insensitive": {"default": 0, "optional": true, "type": "number", "description": "Case insensitive forward proxy bypass", "format": "flag"}, "cipher-without-prio-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"cipher-wo-prio": {"enum": ["SSL3_RSA_DES_192_CBC3_SHA", "SSL3_RSA_DES_40_CBC_SHA", "SSL3_RSA_DES_64_CBC_SHA", "SSL3_RSA_RC4_128_MD5", "SSL3_RSA_RC4_128_SHA", "SSL3_RSA_RC4_40_MD5", "TLS1_RSA_AES_128_SHA", "TLS1_RSA_AES_256_SHA", "TLS1_RSA_EXPORT1024_RC4_56_MD5", "TLS1_RSA_EXPORT1024_RC4_56_SHA", "TLS1_RSA_AES_128_SHA256", "TLS1_RSA_AES_256_SHA256"], "type": "string", "description": "'SSL3_RSA_DES_192_CBC3_SHA': SSL3_RSA_DES_192_CBC3_SHA; 'SSL3_RSA_DES_40_CBC_SHA': SSL3_RSA_DES_40_CBC_SHA; 'SSL3_RSA_DES_64_CBC_SHA': SSL3_RSA_DES_64_CBC_SHA; 'SSL3_RSA_RC4_128_MD5': SSL3_RSA_RC4_128_MD5; 'SSL3_RSA_RC4_128_SHA': SSL3_RSA_RC4_128_SHA; 'SSL3_RSA_RC4_40_MD5': SSL3_RSA_RC4_40_MD5; 'TLS1_RSA_AES_128_SHA': TLS1_RSA_AES_128_SHA; 'TLS1_RSA_AES_256_SHA': TLS1_RSA_AES_256_SHA; 'TLS1_RSA_EXPORT1024_RC4_56_MD5': TLS1_RSA_EXPORT1024_RC4_56_MD5; 'TLS1_RSA_EXPORT1024_RC4_56_SHA': TLS1_RSA_EXPORT1024_RC4_56_SHA; 'TLS1_RSA_AES_128_SHA256': TLS1_RSA_AES_128_SHA256; 'TLS1_RSA_AES_256_SHA256': TLS1_RSA_AES_256_SHA256; ", "format": "enum"}, "optional": true}}]}, "ocspst-sg-minutes": {"description": "Specify update period, in minutes", "format": "number", "optional": true, "not-list": ["ocspst-sg-days", "ocspst-sg-hours"], "maximum": 60, "minimum": 1, "type": "number"}, "starts-with-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"starts-with": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Forward proxy bypass if SNI string starts with another string", "format": "string-rlx"}, "optional": true}}]}, "close-notify": {"default": 0, "optional": true, "type": "number", "description": "Send close notification when terminate connection", "format": "flag"}}}], "type": "array", "$ref": "/axapi/v3/slb/template/client-ssl/{name}"}
    :param dblb_list: {"minItems": 1, "items": {"type": "dblb"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"server-version": {"optional": true, "enum": ["MSSQL2008", "MSSQL2012", "MySQL"], "type": "string", "description": "'MSSQL2008': MSSQL server 2008 or 2008 R2; 'MSSQL2012': MSSQL server 2012; 'MySQL': MySQL server (any version); ", "format": "enum"}, "name": {"description": "DBLB template name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "calc-sha1": {"type": "object", "properties": {"sha1-value": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Cleartext password", "format": "string"}}}, "class-list": {"description": "Specify user/password string class list (Class list name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/class-list"}}}], "type": "array", "$ref": "/axapi/v3/slb/template/dblb/{name}"}
    :param fix_list: {"minItems": 1, "items": {"type": "fix"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"name": {"description": "FIX Template Name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "tag-switching": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"service-group": {"description": "Create a Service Group comprising Servers (Service Group Name)", "format": "string-rlx", "minLength": 1, "maxLength": 127, "type": "string", "$ref": "/axapi/v3/slb/service-group"}, "optional": true, "equals": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Equals (Tag String)", "format": "string"}, "switching-type": {"enum": ["sender-comp-id", "target-comp-id"], "type": "string", "description": "'sender-comp-id': Select service group based on SenderCompID; 'target-comp-id': Select service group based on TargetCompID; ", "format": "enum"}}}]}, "insert-client-ip": {"default": 0, "optional": true, "type": "number", "description": "Insert client ip to tag 11447", "format": "flag"}}}], "type": "array", "$ref": "/axapi/v3/slb/template/fix/{name}"}
    :param sip_list: {"minItems": 1, "items": {"type": "sip"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"server-request-header": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"server-request-header-insert": {"minLength": 1, "maxLength": 127, "type": "string", "description": "Insert a SIP header (Header Content (Format: \"name: value\"))", "format": "string-rlx"}, "server-request-erase-all": {"default": 0, "type": "number", "description": "Erase all headers", "format": "flag"}, "optional": true, "insert-condition-server-request": {"enum": ["insert-if-not-exist", "insert-always"], "type": "string", "description": "'insert-if-not-exist': Only insert the header when it does not exist; 'insert-always': Always insert the header even when there is a header with the same name; ", "format": "enum"}, "server-request-header-erase": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Erase a SIP header (Header Name)", "format": "string-rlx"}}}]}, "keep-server-ip-if-match-acl": {"default": 0, "optional": true, "type": "number", "description": "Use Real Server IP for addresses matching the ACL for a Call-Id", "format": "flag"}, "client-keep-alive": {"default": 0, "optional": true, "type": "number", "description": "Respond client keep-alive packet directly instead of forwarding to server", "format": "flag"}, "alg-source-nat": {"default": 0, "optional": true, "type": "number", "description": "Translate source IP to NAT IP in SIP message when source NAT is used", "format": "flag"}, "server-response-header": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"server-response-header-insert": {"minLength": 1, "maxLength": 127, "type": "string", "description": "Insert a SIP header (Header Content (Format: \"name: value\"))", "format": "string-rlx"}, "server-response-header-erase": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Erase a SIP header (Header Name)", "format": "string-rlx"}, "optional": true, "server-response-erase-all": {"default": 0, "type": "number", "description": "Erase all headers", "format": "flag"}, "insert-condition-server-response": {"enum": ["insert-if-not-exist", "insert-always"], "type": "string", "description": "'insert-if-not-exist': Only insert the header when it does not exist; 'insert-always': Always insert the header even when there is a header with the same name; ", "format": "enum"}}}]}, "server-selection-per-request": {"default": 0, "optional": true, "type": "number", "description": "Force server selection on every SIP request", "format": "flag"}, "client-request-header": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"client-request-header-erase": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Erase a SIP header (Header Name)", "format": "string-rlx"}, "optional": true, "client-request-header-insert": {"minLength": 1, "maxLength": 127, "type": "string", "description": "Insert a SIP header (Header Content (Format: \"name: value\"))", "format": "string-rlx"}, "client-request-erase-all": {"default": 0, "type": "number", "description": "Erase all headers", "format": "flag"}, "insert-condition-client-request": {"enum": ["insert-if-not-exist", "insert-always"], "type": "string", "description": "'insert-if-not-exist': Only insert the header when it does not exist; 'insert-always': Always insert the header even when there is a header with the same name; ", "format": "enum"}}}]}, "service-group": {"description": "service group name", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 127, "type": "string", "$ref": "/axapi/v3/slb/service-group"}, "insert-client-ip": {"default": 0, "optional": true, "type": "number", "description": "Insert Client IP address into SIP header", "format": "flag"}, "failed-client-selection": {"default": 0, "optional": true, "type": "number", "description": "Define action when select client fail", "format": "flag"}, "failed-client-selection-message": {"description": "Send SIP message (includs status code) to server when select client fail(Format: 3 digits(1XX~6XX) space reason)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "not": "drop-when-client-fail", "type": "string"}, "call-id-persist-disable": {"default": 0, "optional": true, "type": "number", "description": "Disable call-ID persistence", "format": "flag"}, "acl-id": {"description": "ACL id", "format": "number", "optional": true, "maximum": 199, "minimum": 100, "not": "acl-name-value", "type": "number", "$ref": "/axapi/v3/access-list/standard"}, "alg-dest-nat": {"default": 0, "optional": true, "type": "number", "description": "Translate VIP to real server IP in SIP message when destination NAT is used", "format": "flag"}, "server-keep-alive": {"default": 0, "optional": true, "type": "number", "description": "Send server keep-alive packet for every persist connection when enable conn-reuse", "format": "flag"}, "client-response-header": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"client-response-erase-all": {"default": 0, "type": "number", "description": "Erase all headers", "format": "flag"}, "insert-condition-client-response": {"enum": ["insert-if-not-exist", "insert-always"], "type": "string", "description": "'insert-if-not-exist': Only insert the header when it does not exist; 'insert-always': Always insert the header even when there is a header with the same name; ", "format": "enum"}, "optional": true, "client-response-header-insert": {"minLength": 1, "maxLength": 127, "type": "string", "description": "Insert a SIP header (Header Content (Format: \"name: value\"))", "format": "string-rlx"}, "client-response-header-erase": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Erase a SIP header (Header Name)", "format": "string-rlx"}}}]}, "failed-server-selection-message": {"description": "Send SIP message (includs status code) to client when select server fail(Format: 3 digits(1XX~6XX) space reason)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "not": "drop-when-server-fail", "type": "string"}, "name": {"description": "SIP Template Name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "exclude-translation": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"translation-value": {"enum": ["start-line", "header", "body"], "type": "string", "description": "'start-line': SIP request line or status line; 'header': SIP message headers; 'body': SIP message body; ", "format": "enum"}, "optional": true, "header-string": {"minLength": 1, "maxLength": 63, "type": "string", "description": "SIP header name", "format": "string-rlx"}}}]}, "interval": {"description": "The interval of keep-alive packet for each persist connection (second)", "format": "number", "default": 30, "optional": true, "maximum": 300, "minimum": 5, "type": "number"}, "dialog-aware": {"default": 0, "optional": true, "type": "number", "description": "Permit system processes dialog session", "format": "flag"}, "failed-server-selection": {"default": 0, "optional": true, "type": "number", "description": "Define action when select server fail", "format": "flag"}, "drop-when-client-fail": {"description": "Drop current SIP message when select client fail", "format": "flag", "default": 0, "optional": true, "not": "failed-client-selection-message", "type": "number"}, "timeout": {"description": "Time in minutes", "format": "number", "default": 30, "optional": true, "maximum": 250, "minimum": 1, "type": "number"}, "drop-when-server-fail": {"description": "Drop current SIP message when select server fail", "format": "flag", "default": 0, "optional": true, "not": "failed-server-selection-message", "type": "number"}, "acl-name-value": {"description": "IPv4 Access List Name", "format": "string", "minLength": 1, "optional": true, "maxLength": 16, "not": "acl-id", "type": "string", "$ref": "/axapi/v3/ip/access-list"}}}], "type": "array", "$ref": "/axapi/v3/slb/template/sip/{name}"}
    :param virtual_server_list: {"minItems": 1, "items": {"type": "virtual-server"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"conn-limit": {"description": "Connection limit", "format": "number", "type": "number", "maximum": 8000000, "minimum": 1, "optional": true}, "conn-rate-limit-no-logging": {"default": 0, "optional": true, "type": "number", "description": "Do not log connection over limit event", "format": "flag"}, "name": {"description": "Virtual server template name", "format": "string", "default": "default", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "conn-limit-reset": {"default": 0, "optional": true, "type": "number", "description": "Send client reset when connection over limit", "format": "flag"}, "conn-rate-limit-reset": {"default": 0, "optional": true, "type": "number", "description": "Send client reset when connection rate over limit", "format": "flag"}, "rate-interval": {"description": "'100ms': Use 100 ms as sampling interval; 'second': Use 1 second as sampling interval; ", "format": "enum", "default": "second", "type": "string", "enum": ["100ms", "second"], "optional": true}, "icmpv6-rate-limit": {"description": "ICMPv6 rate limit (Normal rate limit. If exceeds this limit, drop the ICMP packet that goes over the limit)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}, "subnet-gratuitous-arp": {"default": 0, "optional": true, "type": "number", "description": "Send gratuitous ARP for every IP in the subnet virtual server", "format": "flag"}, "icmpv6-lockup": {"description": "Enter lockup state when ICMP rate exceeds lockup rate limit (Maximum rate limit. If exceeds this limit, drop all ICMP packet for a time period)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}, "conn-rate-limit": {"description": "Connection rate limit", "format": "number", "type": "number", "maximum": 1048575, "minimum": 1, "optional": true}, "icmp-lockup-period": {"description": "Lockup period (second)", "format": "number", "type": "number", "maximum": 16383, "minimum": 1, "optional": true}, "icmpv6-lockup-period": {"description": "Lockup period (second)", "format": "number", "type": "number", "maximum": 16383, "minimum": 1, "optional": true}, "conn-limit-no-logging": {"default": 0, "optional": true, "type": "number", "description": "Do not log connection over limit event", "format": "flag"}, "icmp-rate-limit": {"description": "ICMP rate limit (Normal rate limit. If exceeds this limit, drop the ICMP packet that goes over the limit)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}, "icmp-lockup": {"description": "Enter lockup state when ICMP rate exceeds lockup rate limit (Maximum rate limit. If exceeds this limit, drop all ICMP packet for a time period)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}}}], "type": "array", "$ref": "/axapi/v3/slb/template/virtual-server/{name}"}
    :param dns_list: {"minItems": 1, "items": {"type": "dns"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"query-id-switch": {"default": 0, "optional": true, "type": "number", "description": "Use DNS query ID to create sesion", "format": "flag"}, "name": {"description": "DNS Template Name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "class-list": {"type": "object", "properties": {"lid-list": {"minItems": 1, "items": {"type": "lid"}, "uniqueItems": true, "array": [{"required": ["lidnum"], "properties": {"over-limit-action": {"default": 0, "optional": true, "type": "number", "description": "Action when exceeds limit", "format": "flag"}, "log": {"default": 0, "optional": true, "type": "number", "description": "Log a message", "format": "flag"}, "lidnum": {"description": "Specify a limit ID", "format": "number", "type": "number", "maximum": 31, "minimum": 1, "optional": false}, "action-value": {"optional": true, "enum": ["dns-cache-disable", "dns-cache-enable", "forward"], "type": "string", "description": "'dns-cache-disable': Disable DNS cache when it exceeds limit; 'dns-cache-enable': Enable DNS cache when it exceeds limit; 'forward': Forward the traffic even it exceeds limit; ", "format": "enum"}, "per": {"description": "Per (Number of 100ms)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}, "lockout": {"description": "Don't accept any new connection for certain time (Lockout duration in minutes)", "format": "number", "type": "number", "maximum": 1023, "minimum": 1, "optional": true}, "dns": {"type": "object", "properties": {"cache-action": {"default": "cache-disable", "enum": ["cache-disable", "cache-enable"], "type": "string", "description": "'cache-disable': Disable dns cache; 'cache-enable': Enable dns cache; ", "format": "enum"}, "weight": {"description": "Weight for cache entry", "minimum": 1, "type": "number", "maximum": 7, "format": "number"}, "ttl": {"description": "TTL for cache entry (TTL in seconds)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}}}, "conn-rate-limit": {"description": "Connection rate limit", "format": "number", "type": "number", "maximum": 2147483647, "minimum": 1, "optional": true}, "log-interval": {"description": "Log interval (minute, by default system will log every over limit instance)", "format": "number", "type": "number", "maximum": 255, "minimum": 1, "optional": true}}}], "type": "array", "$ref": "/axapi/v3/slb/template/dns/{name}/class-list/lid/{lidnum}"}, "name": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify a class list name", "format": "string"}}}, "drop": {"description": "Drop the malformed query", "format": "flag", "default": 0, "optional": true, "not": "forward", "type": "number"}, "period": {"description": "Period in minutes", "format": "number", "type": "number", "maximum": 10000, "minimum": 1, "optional": true}, "default-policy": {"optional": true, "enum": ["nocache", "cache"], "type": "string", "description": "'nocache': Cache disable; 'cache': Cache enable; ", "format": "enum"}, "enable-cache-sharing": {"default": 0, "optional": true, "type": "number", "description": "Enable DNS cache sharing", "format": "flag"}, "redirect-to-tcp-port": {"default": 0, "optional": true, "type": "number", "description": "Direct the client to retry with TCP for DNS UDP request", "format": "flag"}, "max-query-length": {"description": "Define Maximum DNS Query Length, default is unlimited (Specify Maximum Length)", "format": "number", "type": "number", "maximum": 4095, "minimum": 1, "optional": true}, "max-cache-size": {"platform-specific-range": 1, "platform-specific-default": 1, "description": "Define maximum cache size (Maximum cache entry per VIP)", "format": "number", "optional": true, "type": "number"}, "forward": {"description": "Forward to service group (Service group name)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 127, "not": "drop", "type": "string", "$ref": "/axapi/v3/slb/service-group"}, "disable-dns-template": {"default": 0, "optional": true, "type": "number", "description": "Disable DNS template", "format": "flag"}, "max-cache-entry-size": {"description": "Define maximum cache entry size (Maximum cache entry size per VIP)", "format": "number", "type": "number", "maximum": 4096, "minimum": 1, "optional": true}}}], "type": "array", "$ref": "/axapi/v3/slb/template/dns/{name}"}
    :param http_list: {"minItems": 1, "items": {"type": "http"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"keep-client-alive": {"default": 0, "optional": true, "type": "number", "description": "Keep client alive", "format": "flag"}, "compression-auto-disable-on-high-cpu": {"description": "Auto-disable software compression on high cpu usage (Disable compression if cpu usage is above threshold. Default is off.)", "format": "number", "type": "number", "maximum": 100, "minimum": 1, "optional": true}, "req-hdr-wait-time": {"default": 0, "optional": true, "type": "number", "description": "HTTP request header wait time before abort connection", "format": "flag"}, "compression-enable": {"default": 0, "optional": true, "type": "number", "description": "Enable Compression", "format": "flag"}, "compression-keep-accept-encoding": {"default": 0, "optional": true, "type": "number", "description": "Keep accept encoding", "format": "flag"}, "failover-url": {"description": "Failover to this URL (Failover URL Name)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 255, "type": "string"}, "redirect-rewrite": {"type": "object", "properties": {"redirect-secure-port": {"description": "Port (Port Number)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "redirect-secure": {"default": 0, "type": "number", "description": "Use HTTPS", "format": "flag"}, "match-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "rewrite-to": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Rewrite to Destination URL String", "format": "string-rlx"}, "redirect-match": {"minLength": 1, "maxLength": 63, "type": "string", "description": "URL Matching (Pattern URL String)", "format": "string-rlx"}}}]}}}, "compression-level": {"description": "compression level, default 1 (compression level value, default is 1)", "format": "number", "type": "number", "maximum": 9, "minimum": 1, "optional": true}, "insert-client-port-header-name": {"description": "HTTP Header Name for inserting Client Port", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "url-hash-last": {"description": "Use the end part of URL to calculate hash value (URL string length to calculate hash value)", "format": "number", "optional": true, "maximum": 128, "minimum": 4, "not": "url-hash-first", "type": "number"}, "use-server-status": {"default": 0, "optional": true, "type": "number", "description": "Use Server-Status header to do URL hashing", "format": "flag"}, "req-hdr-wait-time-val": {"description": "Number of seconds wait for client request header (default is 7)", "format": "number", "default": 7, "optional": true, "maximum": 31, "minimum": 1, "type": "number"}, "response-header-insert-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"response-header-insert-type": {"enum": ["insert-if-not-exist", "insert-always"], "type": "string", "description": "'insert-if-not-exist': Only insert the header when it does not exist; 'insert-always': Always insert the header even when there is a header with the same name; ", "format": "enum"}, "response-header-insert": {"minLength": 1, "maxLength": 127, "type": "string", "description": "Insert a header into HTTP response (Header Content (Format: \"[name]: [value]\"))", "format": "string-rlx"}, "optional": true}}]}, "insert-client-port": {"default": 0, "optional": true, "type": "number", "description": "Insert Client Port address into HTTP header", "format": "flag"}, "retry-on-5xx-per-req": {"description": "Retry http request on HTTP 5xx code for each request", "format": "flag", "default": 0, "optional": true, "not": "retry-on-5xx", "type": "number"}, "url-hash-offset": {"description": "Skip part of URL to calculate hash value (Offset of the URL string)", "format": "number", "type": "number", "maximum": 255, "minimum": 0, "optional": true}, "client-port-hdr-replace": {"default": 0, "optional": true, "type": "number", "description": "Replace the existing header", "format": "flag"}, "non-http-bypass": {"default": 0, "optional": true, "type": "number", "description": "Bypass non-http traffic instead of dropping", "format": "flag"}, "response-header-erase-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"response-header-erase": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Erase a header from HTTP response (Header Name)", "format": "string-rlx"}, "optional": true}}]}, "insert-client-ip": {"default": 0, "optional": true, "type": "number", "description": "Insert Client IP address into HTTP header", "format": "flag"}, "template": {"type": "object", "properties": {"logging": {"description": "Logging template (Logging Config name)", "format": "string", "minLength": 1, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/logging"}}}, "url-switching": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"url-service-group": {"description": "Create a Service Group comprising Servers (Service Group Name)", "format": "string-rlx", "minLength": 1, "maxLength": 127, "type": "string", "$ref": "/axapi/v3/slb/service-group"}, "url-match-string": {"minLength": 1, "maxLength": 63, "type": "string", "description": "URL String", "format": "string-rlx"}, "optional": true, "url-switching-type": {"enum": ["contains", "ends-with", "equals", "starts-with", "url-case-insensitive", "url-hits-enable"], "type": "string", "description": "'contains': Select service group if URL string contains another string; 'ends-with': Select service group if URL string ends with another string; 'equals': Select service group if URL string equals another string; 'starts-with': Select service group if URL string starts with another string; 'url-case-insensitive': Case insensitive URL switching; 'url-hits-enable': Enables URL Hits; ", "format": "enum"}}}]}, "host-switching": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"host-switching-type": {"enum": ["contains", "ends-with", "starts-with", "host-hits-enable"], "type": "string", "description": "'contains': Select service group if hostname contains another string; 'ends-with': Select service group if hostname ends with another string; 'starts-with': Select service group if hostname starts with another string; 'host-hits-enable': Enables Host Hits counters; ", "format": "enum"}, "host-service-group": {"description": "Create a Service Group comprising Servers (Service Group Name)", "format": "string-rlx", "minLength": 1, "maxLength": 127, "type": "string", "$ref": "/axapi/v3/slb/service-group"}, "host-match-string": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Hostname String", "format": "string-rlx"}, "optional": true}}]}, "strict-transaction-switch": {"default": 0, "optional": true, "type": "number", "description": "Force server selection on every HTTP request", "format": "flag"}, "response-content-replace-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "response-new-string": {"minLength": 1, "maxLength": 127, "type": "string", "description": "String will be in the http content", "format": "string-rlx"}, "response-content-replace": {"minLength": 1, "maxLength": 127, "type": "string", "description": "replace the data from HTTP response content (String in the http content need to be replaced)", "format": "string-rlx"}}}]}, "request-header-insert-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "request-header-insert-type": {"enum": ["insert-if-not-exist", "insert-always"], "type": "string", "description": "'insert-if-not-exist': Only insert the header when it does not exist; 'insert-always': Always insert the header even when there is a header with the same name; ", "format": "enum"}, "request-header-insert": {"minLength": 1, "maxLength": 127, "type": "string", "description": "Insert a header into HTTP request (Header Content (Format: \"[name]: [value]\"))", "format": "string-rlx"}}}]}, "compression-minimum-content-length": {"description": "Minimum Content Length (Minimum content length for compression in bytes. Default is 120.)", "format": "number", "default": 120, "optional": true, "maximum": 2147483647, "minimum": 1, "type": "number"}, "request-header-erase-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "request-header-erase": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Erase a header from HTTP request (Header Name)", "format": "string-rlx"}}}]}, "request-line-case-insensitive": {"default": 0, "optional": true, "type": "number", "description": "Parse http request line as case insensitive", "format": "flag"}, "url-hash-persist": {"default": 0, "optional": true, "type": "number", "description": "Use URL's hash value to select server", "format": "flag"}, "retry-on-5xx-per-req-val": {"description": "Number of times to retry (default is 3)", "format": "number", "default": 3, "optional": true, "maximum": 3, "minimum": 1, "type": "number"}, "bypass-sg": {"description": "Select service group for non-http traffic (Service Group Name)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 127, "type": "string", "$ref": "/axapi/v3/slb/service-group"}, "name": {"description": "HTTP Template Name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "retry-on-5xx-val": {"description": "Number of times to retry (default is 3)", "format": "number", "default": 3, "optional": true, "maximum": 3, "minimum": 1, "type": "number"}, "url-hash-first": {"description": "Use the begining part of URL to calculate hash value (URL string length to calculate hash value)", "format": "number", "optional": true, "maximum": 128, "minimum": 4, "not": "url-hash-last", "type": "number"}, "compression-keep-accept-encoding-enable": {"default": 0, "optional": true, "type": "number", "description": "Enable Server Accept Encoding", "format": "flag"}, "client-ip-hdr-replace": {"default": 0, "optional": true, "type": "number", "description": "Replace the existing header", "format": "flag"}, "compression-content-type": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "content-type": {"minLength": 1, "maxLength": 31, "type": "string", "description": "Compression content-type", "format": "string-rlx"}}}]}, "log-retry": {"default": 0, "optional": true, "type": "number", "description": "log when HTTP request retry", "format": "flag"}, "insert-client-ip-header-name": {"description": "HTTP Header Name for inserting Client IP", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "compression-exclude-uri": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "exclude-uri": {"minLength": 1, "maxLength": 31, "type": "string", "description": "Compression exclude uri", "format": "string-rlx"}}}]}, "retry-on-5xx": {"description": "Retry http request on HTTP 5xx code", "format": "flag", "default": 0, "optional": true, "not": "retry-on-5xx-per-req", "type": "number"}, "term-11client-hdr-conn-close": {"default": 0, "optional": true, "type": "number", "description": "Terminate HTTP 1.1 client when req has Connection: close", "format": "flag"}, "compression-exclude-content-type": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"exclude-content-type": {"minLength": 1, "maxLength": 31, "type": "string", "description": "Compression exclude content-type (Compression exclude content type)", "format": "string-rlx"}, "optional": true}}]}}}], "type": "array", "$ref": "/axapi/v3/slb/template/http/{name}"}
    :param virtual_port_list: {"minItems": 1, "items": {"type": "virtual-port"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"aflow": {"default": 0, "optional": true, "type": "number", "description": "Use aFlow to eliminate the traffic surge", "format": "flag"}, "conn-limit": {"description": "Connection limit", "format": "number", "type": "number", "maximum": 8000000, "minimum": 1, "optional": true}, "conn-rate-limit-no-logging": {"default": 0, "optional": true, "type": "number", "description": "Do not log connection over limit event", "format": "flag"}, "drop-unknown-conn": {"default": 0, "optional": true, "type": "number", "description": "Drop conection if receives TCP packet without SYN or RST flag and it does not belong to any existing connections", "format": "flag"}, "name": {"description": "Virtual port template name", "format": "string", "default": "default", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "allow-vip-to-rport-mapping": {"default": 0, "optional": true, "type": "number", "description": "Allow mapping of VIP to real port", "format": "flag"}, "conn-limit-reset": {"default": 0, "optional": true, "type": "number", "description": "Send client reset when connection over limit", "format": "flag"}, "conn-rate-limit-reset": {"default": 0, "optional": true, "type": "number", "description": "Send client reset when connection rate over limit", "format": "flag"}, "rate-interval": {"description": "'100ms': Use 100 ms as sampling interval; 'second': Use 1 second as sampling interval; ", "format": "enum", "default": "second", "type": "string", "enum": ["100ms", "second"], "optional": true}, "dscp": {"description": "Differentiated Services Code Point (DSCP to Real Server IP Mapping Value)", "format": "number", "type": "number", "maximum": 63, "minimum": 1, "optional": true}, "ignore-tcp-msl": {"default": 0, "optional": true, "type": "number", "description": "reclaim TCP resource immediately without MSL", "format": "flag"}, "snat-port-preserve": {"default": 0, "optional": true, "type": "number", "description": "Source NAT Port Preservation", "format": "flag"}, "conn-rate-limit": {"description": "Connection rate limit", "format": "number", "type": "number", "maximum": 1048575, "minimum": 1, "optional": true}, "reset-l7-on-failover": {"default": 0, "optional": true, "type": "number", "description": "Send reset to L7 client and server connection upon a failover", "format": "flag"}, "conn-limit-no-logging": {"default": 0, "optional": true, "type": "number", "description": "Do not log connection over limit event", "format": "flag"}, "snat-msl": {"description": "Source NAT MSL (Source NAT MSL value)", "format": "number", "type": "number", "maximum": 1800, "minimum": 1, "optional": true}, "allow-syn-otherflags": {"default": 0, "optional": true, "type": "number", "description": "Allow initial SYN packet with other flags", "format": "flag"}, "reset-unknown-conn": {"default": 0, "optional": true, "type": "number", "description": "Send reset back if receives TCP packet without SYN or RST flag and it does not belong to any existing connections", "format": "flag"}}}], "type": "array", "$ref": "/axapi/v3/slb/template/virtual-port/{name}"}
    :param cipher_list: {"minItems": 1, "items": {"type": "cipher"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"name": {"description": "Cipher Template Name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "cipher-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"priority": {"description": "Cipher priority (Cipher priority (default 1))", "format": "number", "default": 1, "maximum": 100, "minimum": 1, "type": "number"}, "cipher-suite": {"enum": ["SSL3_RSA_DES_192_CBC3_SHA", "SSL3_RSA_DES_40_CBC_SHA", "SSL3_RSA_DES_64_CBC_SHA", "SSL3_RSA_RC4_128_MD5", "SSL3_RSA_RC4_128_SHA", "SSL3_RSA_RC4_40_MD5", "TLS1_RSA_AES_128_SHA", "TLS1_RSA_AES_256_SHA", "TLS1_RSA_EXPORT1024_RC4_56_MD5", "TLS1_RSA_EXPORT1024_RC4_56_SHA", "TLS1_RSA_AES_128_SHA256", "TLS1_RSA_AES_256_SHA256"], "type": "string", "description": "'SSL3_RSA_DES_192_CBC3_SHA': SSL3_RSA_DES_192_CBC3_SHA; 'SSL3_RSA_DES_40_CBC_SHA': SSL3_RSA_DES_40_CBC_SHA; 'SSL3_RSA_DES_64_CBC_SHA': SSL3_RSA_DES_64_CBC_SHA; 'SSL3_RSA_RC4_128_MD5': SSL3_RSA_RC4_128_MD5; 'SSL3_RSA_RC4_128_SHA': SSL3_RSA_RC4_128_SHA; 'SSL3_RSA_RC4_40_MD5': SSL3_RSA_RC4_40_MD5; 'TLS1_RSA_AES_128_SHA': TLS1_RSA_AES_128_SHA; 'TLS1_RSA_AES_256_SHA': TLS1_RSA_AES_256_SHA; 'TLS1_RSA_EXPORT1024_RC4_56_MD5': TLS1_RSA_EXPORT1024_RC4_56_MD5; 'TLS1_RSA_EXPORT1024_RC4_56_SHA': TLS1_RSA_EXPORT1024_RC4_56_SHA; 'TLS1_RSA_AES_128_SHA256': TLS1_RSA_AES_128_SHA256; 'TLS1_RSA_AES_256_SHA256': TLS1_RSA_AES_256_SHA256; ", "format": "enum"}, "optional": true}}]}}}], "type": "array", "$ref": "/axapi/v3/slb/template/cipher/{name}"}
    :param policy_list: {"minItems": 1, "items": {"type": "policy"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"use-destination-ip": {"default": 0, "optional": true, "type": "number", "description": "Use destination IP to match the policy", "format": "flag"}, "name": {"description": "Policy template name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "over-limit": {"default": 0, "optional": true, "type": "number", "description": "Specify operation in case over limit", "format": "flag"}, "class-list": {"type": "object", "properties": {"header-name": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify L7 header name", "format": "string"}, "client-ip-l7-header": {"default": 0, "not": "client-ip-l3-dest", "type": "number", "description": "Use extract client IP address from L7 header", "format": "flag"}, "client-ip-l3-dest": {"default": 0, "not": "client-ip-l7-header", "type": "number", "description": "Use destination IP as client IP address", "format": "flag"}, "lid-list": {"minItems": 1, "items": {"type": "lid"}, "uniqueItems": true, "array": [{"required": ["lidnum"], "properties": {"request-limit": {"description": "Request limit (Specify request limit)", "format": "number", "type": "number", "maximum": 1048575, "minimum": 0, "optional": true}, "conn-limit": {"description": "Connection limit", "format": "number", "type": "number", "maximum": 1048575, "minimum": 0, "optional": true}, "interval": {"description": "Specify log interval in minutes, by default system will log every over limit instance", "format": "number", "type": "number", "maximum": 255, "minimum": 1, "optional": true}, "log": {"default": 0, "optional": true, "type": "number", "description": "Log a message", "format": "flag"}, "dns64": {"type": "object", "properties": {"exclusive-answer": {"default": 0, "type": "number", "description": "Exclusive Answer in DNS Response", "format": "flag"}, "prefix": {"type": "string", "description": "IPv6 prefix", "format": "ipv6-address-plen"}, "disable": {"default": 0, "type": "number", "description": "Disable", "format": "flag"}}}, "lidnum": {"description": "Specify a limit ID", "format": "number", "type": "number", "maximum": 31, "minimum": 1, "optional": false}, "request-rate-limit": {"description": "Request rate limit (Specify request rate limit)", "format": "number", "type": "number", "maximum": 4294967295, "minimum": 1, "optional": true}, "conn-per": {"description": "Per (Specify interval in number of 100ms)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}, "request-per": {"description": "Per (Specify interval in number of 100ms)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}, "conn-rate-limit": {"description": "Specify connection rate limit", "format": "number", "type": "number", "maximum": 2147483647, "minimum": 1, "optional": true}, "lockout": {"description": "Don't accept any new connection for certain time (Lockout duration in minutes)", "format": "number", "type": "number", "maximum": 1023, "minimum": 1, "optional": true}, "action-value": {"optional": true, "enum": ["forward", "reset"], "type": "string", "description": "'forward': Forward the traffic even it exceeds limit; 'reset': Reset the connection when it exceeds limit; ", "format": "enum"}, "over-limit-action": {"default": 0, "optional": true, "type": "number", "description": "Set action when exceeds limit", "format": "flag"}}}], "type": "array", "$ref": "/axapi/v3/slb/template/policy/{name}/class-list/lid/{lidnum}"}, "name": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Class list name or geo-location-class-list name", "format": "string"}}}, "full-domain-tree": {"default": 0, "optional": true, "type": "number", "description": "Share counters between geo-location and sub regions", "format": "flag"}, "interval": {"description": "Log interval (minute)", "format": "number", "type": "number", "maximum": 255, "minimum": 1, "optional": true}, "share": {"default": 0, "optional": true, "type": "number", "description": "Share counters between virtual ports and virtual servers", "format": "flag"}, "over-limit-lockup": {"description": "Don't accept any new connection for certain time (Lockup duration (minute))", "format": "number", "type": "number", "maximum": 127, "minimum": 1, "optional": true}, "over-limit-logging": {"default": 0, "optional": true, "type": "number", "description": "Log a message", "format": "flag"}, "bw-list-id": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"pbslb-interval": {"description": "Specify logging interval in minutes", "format": "number", "default": 3, "maximum": 60, "minimum": 0, "type": "number"}, "action-interval": {"description": "Specify logging interval in minute (default is 3)", "format": "number", "default": 3, "maximum": 60, "minimum": 0, "type": "number"}, "service-group": {"description": "Specify a service group (Specify the service group name)", "format": "string-rlx", "minLength": 1, "maxLength": 127, "not": "bw-list-action", "type": "string", "$ref": "/axapi/v3/slb/service-group"}, "logging-drp-rst": {"default": 0, "type": "number", "description": "Configure PBSLB logging", "format": "flag"}, "fail": {"default": 0, "type": "number", "description": "Only log unsuccessful connections", "format": "flag"}, "pbslb-logging": {"default": 0, "type": "number", "description": "Configure PBSLB logging", "format": "flag"}, "optional": true, "id": {"description": "Specify id that maps to service group (The id number)", "minimum": 0, "type": "number", "maximum": 31, "format": "number"}, "bw-list-action": {"not": "service-group", "enum": ["drop", "reset"], "type": "string", "description": "'drop': drop the packet; 'reset': Send reset back; ", "format": "enum"}}}]}, "bw-list-name": {"description": "Specify a blacklist/whitelist name", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "overlap": {"default": 0, "optional": true, "type": "number", "description": "Use overlap mode for geo-location to do longest match", "format": "flag"}, "timeout": {"description": "Define timeout value of PBSLB dynamic entry (Timeout value (minute, default is 5))", "format": "number", "type": "number", "maximum": 127, "minimum": 1, "optional": true}, "over-limit-reset": {"default": 0, "optional": true, "type": "number", "description": "Reset the connection when it exceeds limit", "format": "flag"}}}], "type": "array", "$ref": "/axapi/v3/slb/template/policy/{name}"}
    :param server_list: {"minItems": 1, "items": {"type": "server"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"health-check-disable": {"description": "Disable configured health check configuration", "format": "flag", "default": 0, "optional": true, "not": "health-check", "type": "number"}, "stats-data-action": {"description": "'stats-data-enable': Enable statistical data collection for real server; 'stats-data-disable': Disable statistical data collection for real server; ", "format": "enum", "default": "stats-data-enable", "type": "string", "enum": ["stats-data-enable", "stats-data-disable"], "optional": true}, "spoofing-cache": {"default": 0, "optional": true, "type": "number", "description": "Servers under the template are spoofing cache", "format": "flag"}, "weight": {"description": "Weight for the Real Servers (Connection Weight)", "format": "number", "type": "number", "maximum": 100, "minimum": 1, "optional": true}, "slow-start": {"default": 0, "optional": true, "type": "number", "description": "Slowly ramp up the connection number after server is up", "format": "flag"}, "conn-limit": {"description": "Connection limit", "format": "number", "type": "number", "maximum": 8000000, "minimum": 1, "optional": true}, "initial-slow-start": {"description": "Initial slow start connection limit (default 128)", "format": "number", "default": 128, "optional": true, "maximum": 4095, "minimum": 1, "type": "number"}, "max-dynamic-server": {"description": "Maximum dynamic server number (Maximum dynamic server number (default is 255))", "format": "number", "default": 255, "optional": true, "maximum": 1023, "minimum": 1, "type": "number"}, "rate-interval": {"description": "'100ms': Use 100 ms as sampling interval; 'second': Use 1 second as sampling interval; ", "format": "enum", "default": "second", "type": "string", "enum": ["100ms", "second"], "optional": true}, "till": {"description": "Slow start ends when slow start connection limit reaches a number (default 4096) (Slow start ends when connection limit reaches this number)", "format": "number", "default": 4096, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}, "add": {"description": "Slow start connection limit add by a number every interval (Add by this number every interval)", "format": "number", "optional": true, "maximum": 4095, "minimum": 1, "not": "times", "type": "number"}, "min-ttl-ratio": {"description": "Minimum TTL to DNS query interval ratio (Minimum TTL ratio (default is 2))", "format": "number", "default": 2, "optional": true, "maximum": 15, "minimum": 1, "type": "number"}, "dynamic-server-prefix": {"description": "Prefix of dynamic server (Prefix of dynamic server (default is \"DRS\"))", "format": "string", "default": "DRS", "minLength": 1, "optional": true, "maxLength": 3, "type": "string"}, "resume": {"description": "Resume accepting new connection after connection number drops below threshold (Connection resume threshold)", "format": "number", "type": "number", "maximum": 1048575, "minimum": 1, "optional": true}, "every": {"description": "Slow start connection limit increment interval (default 10)", "format": "number", "default": 10, "optional": true, "maximum": 60, "minimum": 1, "type": "number"}, "conn-limit-no-logging": {"default": 0, "optional": true, "type": "number", "description": "Do not log connection over limit event", "format": "flag"}, "extended-stats": {"default": 0, "optional": true, "type": "number", "description": "Enable extended statistics on real server", "format": "flag"}, "conn-rate-limit-no-logging": {"default": 0, "optional": true, "type": "number", "description": "Do not log connection over limit event", "format": "flag"}, "name": {"description": "Server template name", "format": "string", "default": "default", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "times": {"description": "Slow start connection limit multiply by a number every interval (default 2) (Multiply by this number every interval)", "format": "number", "default": 2, "optional": true, "maximum": 10, "minimum": 2, "not": "add", "type": "number"}, "log-selection-failure": {"default": 0, "optional": true, "type": "number", "description": "Enable real-time logging for server selection failure event", "format": "flag"}, "conn-rate-limit": {"description": "Connection rate limit", "format": "number", "type": "number", "maximum": 1048575, "minimum": 1, "optional": true}, "dns-query-interval": {"description": "The interval to query DNS server for the hostname (DNS query interval (in minute, default is 10))", "format": "number", "default": 10, "optional": true, "maximum": 1440, "minimum": 1, "type": "number"}, "health-check": {"description": "Health Check Monitor (Health monitor name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "not": "health-check-disable", "type": "string", "$ref": "/axapi/v3/health/monitor"}}}], "type": "array", "$ref": "/axapi/v3/slb/template/server/{name}"}
    :param monitor_list: {"minItems": 1, "items": {"type": "monitor"}, "uniqueItems": true, "array": [{"required": ["id"], "properties": {"clear-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"clear-sequence": {"description": "Specify the port physical port number", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}, "clear-all-sequence": {"description": "Sequence number (Specify the port physical port number)", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}, "optional": true, "sessions": {"enum": ["all", "sequence"], "type": "string", "description": "'all': Clear all sessions; 'sequence': Sequence number; ", "format": "enum"}}}]}, "link-enable-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ena-sequence": {"description": "Sequence number (Specify the physical port number)", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}, "enaeth": {"type": "number", "description": "Specify the physical port number (Ethernet interface number)", "format": "interface"}, "optional": true}}]}, "link-up-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"linkup-ethernet3": {"type": "number", "description": "Specify the port physical port number (Ethernet interface number)", "format": "interface"}, "linkup-ethernet2": {"type": "number", "description": "Specify the port physical port number (Ethernet interface number)", "format": "interface"}, "linkup-ethernet1": {"type": "number", "description": "Specify the port physical port number (Ethernet interface number)", "format": "interface"}, "link-up-sequence1": {"description": "Sequence number (Specify the port physical port number)", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}, "link-up-sequence3": {"description": "Sequence number (Specify the port physical port number)", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}, "link-up-sequence2": {"description": "Sequence number (Specify the port physical port number)", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}, "optional": true}}]}, "link-down-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"link-down-sequence1": {"description": "Sequence number (Specify the port physical port number)", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}, "link-down-sequence2": {"description": "Sequence number (Specify the port physical port number)", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}, "link-down-sequence3": {"description": "Sequence number (Specify the port physical port number)", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}, "optional": true, "linkdown-ethernet2": {"type": "number", "description": "Specify the port physical port number (Ethernet interface number)", "format": "interface"}, "linkdown-ethernet3": {"type": "number", "description": "Specify the port physical port number (Ethernet interface number)", "format": "interface"}, "linkdown-ethernet1": {"type": "number", "description": "Specify the port physical port number (Ethernet interface number)", "format": "interface"}}}]}, "link-disable-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"dis-sequence": {"description": "Sequence number (Specify the physical port number)", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}, "diseth": {"type": "number", "description": "Specify the physical port number (Ethernet interface number)", "format": "interface"}, "optional": true}}]}, "monitor-relation": {"description": "'monitor-and': Configures the monitors in current template to work with AND logic; 'monitor-or': Configures the monitors in current template to work with OR logic; ", "format": "enum", "default": "monitor-and", "type": "string", "enum": ["monitor-and", "monitor-or"], "optional": true}, "id": {"description": "Monitor template ID Number", "format": "number", "type": "number", "maximum": 16, "minimum": 1, "optional": false}}}], "type": "array", "$ref": "/axapi/v3/slb/template/monitor/{id}"}
    :param tcp_proxy_list: {"minItems": 1, "items": {"type": "tcp-proxy"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"qos": {"description": "QOS level (number)", "format": "number", "type": "number", "maximum": 63, "minimum": 1, "optional": true}, "init-cwnd": {"description": "The initial congestion control window size (packets), default is 4 (number)", "format": "number", "default": 4, "optional": true, "maximum": 10, "minimum": 1, "type": "number"}, "idle-timeout": {"description": "Idle Timeout (sec), default is 600 (number)", "format": "number", "default": 600, "optional": true, "maximum": 2097151, "minimum": 1, "type": "number"}, "fin-timeout": {"description": "FIN timeout (sec), default is 5 (number)", "format": "number", "default": 5, "optional": true, "maximum": 60, "minimum": 1, "type": "number"}, "half-open-idle-timeout": {"description": "TCP Half Open Idle Timeout (sec), default is off (number)", "format": "number", "type": "number", "maximum": 60, "minimum": 1, "optional": true}, "reno": {"default": 0, "optional": true, "type": "number", "description": "Enable Reno Congestion Control Algorithm", "format": "flag"}, "timewait": {"description": "Timewait Threshold (sec), default 5 (number)", "format": "number", "default": 5, "optional": true, "maximum": 60, "minimum": 1, "type": "number"}, "dynamic-buffer-allocation": {"default": 0, "optional": true, "type": "number", "description": "Optimally adjust the transmit and receive buffer sizes of TCP proxy while keeping their sum constant", "format": "flag"}, "alive-if-active": {"default": 0, "optional": true, "type": "number", "description": "keep connection alive if active traffic", "format": "flag"}, "mss": {"description": "Responding MSS to use if client MSS is large, default is off (number)", "format": "number", "default": 1460, "optional": true, "maximum": 4312, "minimum": 128, "type": "number"}, "keepalive-interval": {"description": "Interval between keepalive probes (sec), default is off (number)", "format": "number", "type": "number", "maximum": 12000, "minimum": 60, "optional": true}, "retransmit-retries": {"description": "Number of Retries for Retransmit, default is 3", "format": "number", "default": 3, "optional": true, "maximum": 20, "minimum": 1, "type": "number"}, "insert-client-ip": {"default": 0, "optional": true, "type": "number", "description": "Insert client ip into TCP option", "format": "flag"}, "nagle": {"default": 0, "optional": true, "type": "number", "description": "Enable Nagle Algorithm", "format": "flag"}, "force-delete-timeout-100ms": {"description": "The maximum time that a session can stay in the system before being deleted, default is off (number in 100ms)", "format": "number", "optional": true, "maximum": 31, "minimum": 1, "not": "force-delete-timeout", "type": "number"}, "initial-window-size": {"description": "Set the initial window size, default is off (number)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}, "keepalive-probes": {"description": "Number of keepalive probes sent, default is off", "format": "number", "type": "number", "maximum": 10, "minimum": 2, "optional": true}, "ack-aggressiveness": {"description": "'low': Delayed ACK; 'medium': Delayed ACK, with ACK on each packet with PUSH flag; 'high': ACK on each packet; ", "format": "enum", "default": "low", "type": "string", "enum": ["low", "medium", "high"], "optional": true}, "backend-wscale": {"description": "The TCP window scale used for the server side, default is off (number)", "format": "number", "type": "number", "maximum": 14, "minimum": 1, "optional": true}, "reset-rev": {"default": 0, "optional": true, "type": "number", "description": "send reset to client if error happens", "format": "flag"}, "receive-buffer": {"description": "TCP Receive Buffer (default 50k) (number)", "format": "number", "default": 51200, "optional": true, "maximum": 2147483647, "minimum": 1, "type": "number"}, "transmit-buffer": {"description": "TCP Transmit Buffer (default 50k) (number)", "format": "number", "default": 51200, "optional": true, "maximum": 2147483647, "minimum": 1, "type": "number"}, "name": {"description": "TCP Proxy Template Name", "format": "string", "default": "default", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "reset-fwd": {"default": 0, "optional": true, "type": "number", "description": "send reset to server if error happens", "format": "flag"}, "syn-retries": {"description": "SYN Retry Numbers, default is 5", "format": "number", "default": 5, "optional": true, "maximum": 20, "minimum": 1, "type": "number"}, "force-delete-timeout": {"description": "The maximum time that a session can stay in the system before being deleted, default is off (number (second))", "format": "number", "optional": true, "maximum": 31, "minimum": 1, "not": "force-delete-timeout-100ms", "type": "number"}, "half-close-idle-timeout": {"description": "TCP Half Close Idle Timeout (sec), default is off (number)", "format": "number", "type": "number", "maximum": 120, "minimum": 60, "optional": true}}}], "type": "array", "$ref": "/axapi/v3/slb/template/tcp-proxy/{name}"}
    :param ftp_list: {"minItems": 1, "items": {"type": "ftp"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"to": {"description": "End range of FTP Active mode port", "format": "number", "type": "number", "maximum": 65534, "minimum": 1, "optional": true}, "active-mode-port": {"default": 0, "optional": true, "type": "number", "description": "Non-Standard FTP Active mode port", "format": "flag"}, "active-mode-port-val": {"description": "Non-Standard FTP Active mode port", "format": "number", "optional": true, "maximum": 65534, "minimum": 1, "not": "any", "type": "number"}, "name": {"description": "FTP template name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "any": {"description": "Allow any FTP Active mode port", "format": "flag", "default": 0, "optional": true, "not": "active-mode-port-val", "type": "number"}}}], "type": "array", "$ref": "/axapi/v3/slb/template/ftp/{name}"}
    :param server_ssl_list: {"minItems": 1, "items": {"type": "server-ssl"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"session-cache-timeout": {"description": "Session Cache Timeout (Timeout value, in seconds)", "format": "number", "type": "number", "maximum": 7200, "minimum": 1, "optional": true}, "name": {"description": "Server SSL Template Name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "session-cache-size": {"description": "Session Cache Size (Specify 0 to disable Session ID reuse.)", "format": "number", "type": "number", "maximum": 128, "minimum": 0, "optional": true}, "encrypted": {"optional": true, "type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}, "cipher-template": {"description": "Cipher Template (Cipher Config Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "session-ticket-enable": {"default": 0, "optional": true, "type": "number", "description": "Enable server side session ticket support", "format": "flag"}, "cert": {"description": "Specify Client certificate (Certificate Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 255, "type": "string"}, "version": {"description": "TLS/SSL version, default is TLS1.0 (TLS/SSL version: 30-SSLv3.0, 31-TLSv1.0, 32-TLSv1.1 and 33-TLSv1.2)", "format": "number", "type": "number", "maximum": 33, "minimum": 30, "optional": true}, "forward-proxy-enable": {"default": 0, "optional": true, "type": "number", "description": "Enable SSL forward proxy", "format": "flag"}, "close-notify": {"default": 0, "optional": true, "type": "number", "description": "Send close notification when terminate connection", "format": "flag"}, "key": {"description": "Client private-key (Key Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 255, "type": "string"}, "cipher-without-prio-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"cipher-wo-prio": {"enum": ["SSL3_RSA_DES_192_CBC3_SHA", "SSL3_RSA_DES_40_CBC_SHA", "SSL3_RSA_DES_64_CBC_SHA", "SSL3_RSA_RC4_128_MD5", "SSL3_RSA_RC4_128_SHA", "SSL3_RSA_RC4_40_MD5", "TLS1_RSA_AES_128_SHA", "TLS1_RSA_AES_256_SHA", "TLS1_RSA_EXPORT1024_RC4_56_MD5", "TLS1_RSA_EXPORT1024_RC4_56_SHA", "TLS1_RSA_AES_128_SHA256", "TLS1_RSA_AES_256_SHA256"], "type": "string", "description": "'SSL3_RSA_DES_192_CBC3_SHA': SSL3_RSA_DES_192_CBC3_SHA; 'SSL3_RSA_DES_40_CBC_SHA': SSL3_RSA_DES_40_CBC_SHA; 'SSL3_RSA_DES_64_CBC_SHA': SSL3_RSA_DES_64_CBC_SHA; 'SSL3_RSA_RC4_128_MD5': SSL3_RSA_RC4_128_MD5; 'SSL3_RSA_RC4_128_SHA': SSL3_RSA_RC4_128_SHA; 'SSL3_RSA_RC4_40_MD5': SSL3_RSA_RC4_40_MD5; 'TLS1_RSA_AES_128_SHA': TLS1_RSA_AES_128_SHA; 'TLS1_RSA_AES_256_SHA': TLS1_RSA_AES_256_SHA; 'TLS1_RSA_EXPORT1024_RC4_56_MD5': TLS1_RSA_EXPORT1024_RC4_56_MD5; 'TLS1_RSA_EXPORT1024_RC4_56_SHA': TLS1_RSA_EXPORT1024_RC4_56_SHA; 'TLS1_RSA_AES_128_SHA256': TLS1_RSA_AES_128_SHA256; 'TLS1_RSA_AES_256_SHA256': TLS1_RSA_AES_256_SHA256; ", "format": "enum"}, "optional": true}}]}, "passphrase": {"description": "Password Phrase", "format": "password", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "server-certificate-error": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"error-type": {"enum": ["email", "ignore", "logging", "trap"], "type": "string", "description": "'email': Notify the error via email; 'ignore': Ignore the error, which mean the connection can continue; 'logging': Log the error; 'trap': Notify the error by SNMP trap; ", "format": "enum"}, "optional": true}}]}, "ca-certs": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ca-cert": {"minLength": 1, "maxLength": 255, "type": "string", "description": "Specify CA certificate", "format": "string"}, "optional": true}}]}}}], "type": "array", "$ref": "/axapi/v3/slb/template/server-ssl/{name}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/template`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "template"
        self.a10_url="/axapi/v3/slb/template"
        self.DeviceProxy = ""
        self.logging_list = []
        self.cache_list = []
        self.port_list = []
        self.connection_reuse_list = []
        self.smpp_list = []
        self.smtp_list = []
        self.external_service_list = []
        self.tcp_list = []
        self.diameter_list = []
        self.udp_list = []
        self.http_policy_list = []
        self.client_ssl_list = []
        self.dblb_list = []
        self.fix_list = []
        self.persist = {}
        self.sip_list = []
        self.virtual_server_list = []
        self.dns_list = []
        self.http_list = []
        self.virtual_port_list = []
        self.cipher_list = []
        self.policy_list = []
        self.server_list = []
        self.monitor_list = []
        self.tcp_proxy_list = []
        self.ftp_list = []
        self.server_ssl_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)


